@@ -3,7 +3,10 @@ from __future__ import annotations
 import functools
 import logging
 
-from ewoksorange.bindings import OWEwoksWidgetWithTaskStack
+from ewoksorange.bindings import (
+    OWEwoksWidgetWithTaskStack,
+    OWEwoksWidgetOneThreadPerRun,
+)
 from ewoksorange.bindings.owwidgets import invalid_data
 from orangewidget.widget import OWBaseWidget
 from processview.core.manager import DatasetState, ProcessManager
@@ -74,6 +77,7 @@ class TomwerWithStackStack(
     def __init__(self, parent, process_id=None, *args, **kwargs):
         OWEwoksWidgetWithTaskStack.__init__(self, parent, args, kwargs)
         _SuperviseMixIn.__init__(self, process_id=process_id)
+        WidgetLongProcessing.__init__(self)
 
         self.task_executor_queue.sigComputationStarted.connect(self._startProcessing)
         self.task_executor_queue.sigComputationEnded.connect(self._endProcessing)
@@ -91,3 +95,11 @@ class TomwerWithStackStack(
                 channel.send(None)  # or channel.invalidate?
             else:
                 channel.send(var.value)
+
+
+class TomwerUnsupervisedOneThreadPerRun(
+    OWEwoksWidgetOneThreadPerRun, WidgetLongProcessing, openclass=True
+):
+    """EwoksOrange OWEwoksWidgetOneThreadPerRun with API to provide dataset state information"""
+
+    pass
