@@ -42,48 +42,44 @@ class NXTomomillMixIn:
 
         if os.path.exists(cfg_file):
             try:
-                configuration = self.CONFIG_CLS.from_cfg_file(
-                    cfg_file
+                configuration = (
+                    self.CONFIG_CLS.from_cfg_file(cfg_file)
+                    .to_nested_model()
+                    .model_dump()
                 )  # pylint: disable=E1102
             except Exception as e:
                 self._logger.error(
                     f"Fail to use configuration file {cfg_file}. Error is {e}. No conversion will be done."
                 )
-            else:
-                default_inputs = {
-                    keyword: configuration.to_dict(),
-                }
+                configuration = {}
         else:
-            default_inputs = {
-                keyword: self.CONFIG_CLS().to_dict(),  # pylint: disable=E1102
-            }
+            configuration = (
+                self.CONFIG_CLS().to_nested_model().model_dump()
+            )  # pylint: disable=E1102
+
+        # make sure section name are upper case
+        configuration = {key.upper(): value for key, value in configuration.items()}
 
         # hack: try to upgrade sample|detector_x|y_pixel_keys
         # otherwise has they have the same values and are tuples they have the same id and orange raises an
         # dump_literals raise a ValueError - check_relaxed - is a recursive structure
-        default_inputs_keys_section = default_inputs.get(keyword, {}).get(
-            "KEYS_SECTION", {}
-        )
-        for key in (
-            "sample_x_detector_keys",
-            "sample_y_detector_keys",
-            "detector_x_detector_keys",
-            "detector_y_detector_keys",
-            "sample_detector_distance",
-            "detector_x_pixel_size_keys",
-            "detector_y_pixel_size_keys",
-            "sample_x_pixel_size_keys",
-            "sample_y_pixel_size_keys",
-        ):
-            try:
-                default_inputs_keys_section[key] = list(
-                    default_inputs_keys_section[key]
-                )
-            except KeyError:
-                pass
+        for _, section_value in configuration.items():
+            elments_having_tuple_as_value = {
+                key: value
+                for key, value in section_value.items()
+                if isinstance(value, tuple)
+            }
+
+            for key in elments_having_tuple_as_value:
+                try:
+                    section_value[key] = list(section_value[key])
+                except KeyError:
+                    pass
 
         self.update_default_inputs(
-            **default_inputs,
+            **{
+                keyword: configuration,
+            }
         )
 
     def _get_task_arguments(self):
