@@ -4,8 +4,10 @@ import logging
 import os
 from copy import copy
 
-from nxtomomill.io.config import TomoHDF5Config as HDF5Config
+from nxtomomill.models.h52nx import H52nxModel
 from orangewidget import gui
+from orangewidget.settings import Setting
+
 from silx.gui import qt
 from silx.gui.utils import blockSignals
 
@@ -58,7 +60,7 @@ class NXTomomillOW(
     want_control_area = False
     resizing_enabled = True
 
-    CONFIG_CLS = HDF5Config
+    CONFIG_CLS = H52nxModel
 
     LOGGER = logger
 
@@ -68,6 +70,8 @@ class NXTomomillOW(
         "serialize_output_data",
     )
 
+    _detector_mechanical_flips = Setting(tuple([False, False]))
+
     def __init__(self, parent=None):
         TomwerWithStackStack.__init__(self, parent=parent)
         NXTomomillMixIn.__init__(self)
@@ -93,8 +97,14 @@ class NXTomomillOW(
         self.widget.sigUpdated.connect(self._updateSettings)
 
         # set default configuration is no existing configuration file defined in the settings
+        # note: historically the model was a 'nested one'. Let's keep it as it is for now
+        # to avoid any breaking modification
+        default_config = H52nxModel().to_nested_model()
+        default_config = {
+            key.upper(): value for key, value in default_config.model_dump().items()
+        }
         self.update_default_inputs(
-            h5_to_nx_configuration=HDF5Config().to_dict(),
+            h5_to_nx_configuration=default_config,
         )
         if isinstance(self.task_output_changed_callbacks, set):
             self.task_output_changed_callbacks.add(self._notify_state)
@@ -120,6 +130,7 @@ class NXTomomillOW(
         if isinstance(output_dir, ProcessDataOutputDirMode):
             output_dir = output_dir.value
         self._ewoks_default_inputs["output_dir"] = output_dir  # pylint: disable=E1137
+        self._detector_mechanical_flips = self.widget._dialog.getMechanicalFlips()
 
     @property
     def request_input(self):
@@ -153,7 +164,7 @@ class NXTomomillOW(
         :param bliss_url: string at entry@file format
         """
         logger.processStarted(f"Start translate {bliss_url} to NXTomo")
-        self.__configuration_cache = HDF5Config.from_dict(
+        self.__configuration_cache = H52nxModel.from_dict(
             copy(self.get_default_input_values()["h5_to_nx_configuration"])
         )
 
@@ -177,6 +188,10 @@ class NXTomomillOW(
         self.__configuration_cache.overwrite = True
         self.__configuration_cache.request_input = self.request_input
         self.__configuration_cache.file_extension = ".nx"
+        (
+            self.__configuration_cache.mechanical_lr_flip,
+            self.__configuration_cache.mechanical_ud_flip,
+        ) = self.widget._dialog.getMechanicalFlips()
 
         self._processBlissScan(bliss_scan)
 
@@ -187,7 +202,7 @@ class NXTomomillOW(
             msg = OverwriteMessage(self)
             text = "NXtomomill will overwrite \n %s. Do you agree ?" % file_path
             msg.setText(text)
-            if msg.exec_():
+            if msg.exec():
                 self._canOverwriteOutputs = msg.canOverwriteAll()
                 return True
             else:
@@ -249,20 +264,8 @@ class NXTomomillOW(
                 self.widget.setOutputFolder(
                     self._ewoks_default_inputs["output_dir"]  # pylint: disable=E1136
                 )
-
-    def getHDF5Config(self):
-        configuration_file = self.widget.getCFGFilePath()
-        if configuration_file in (None, ""):
-            configuration = HDF5Config()
-        else:
-            try:
-                configuration = HDF5Config.from_cfg_file(configuration_file)
-            except Exception as e:
-                logger.error(
-                    f"Fail to use configuration file {configuration_file}. Error is {e}. No conversion will be done."
-                )
-                return None
-        return configuration
+            if len(self._detector_mechanical_flips) == 2:
+                self.widget._dialog.setMechanicalFlips(*self._detector_mechanical_flips)
 
     def _saveNXTomoCfgFile(self, cfg_file):
         super()._saveNXTomoCfgFile(cfg_file, keyword="h5_to_nx_configuration")
@@ -300,7 +303,7 @@ class NXTomomillOW(
             task_executor = self.sender()
             task_suceeded = task_executor.succeeded
             config = task_executor.current_task.inputs.h5_to_nx_configuration
-            config = HDF5Config.from_dict(config)
+            config = H52nxModel.from_dict(config)
             scan = task_executor.current_task.outputs.data
             if task_suceeded:
                 self.notify_succeed(scan=scan)
