@@ -46,32 +46,39 @@ class PythonSyntaxHighlighter(qt.QSyntaxHighlighter):
         self.keywords = list(keyword.kwlist)
 
         self.rules = [
-            (qt.QRegExp(r"\b%s\b" % kwd), self.keywordFormat) for kwd in self.keywords
+            (qt.QRegularExpression(r"\b%s\b" % kwd), self.keywordFormat)
+            for kwd in self.keywords
         ] + [
-            (qt.QRegExp(r"\bdef\s+([A-Za-z_]+[A-Za-z0-9_]+)\s*\("), self.defFormat),
-            (qt.QRegExp(r"\bclass\s+([A-Za-z_]+[A-Za-z0-9_]+)\s*\("), self.defFormat),
-            (qt.QRegExp(r"'.*'"), self.stringFormat),
-            (qt.QRegExp(r'".*"'), self.stringFormat),
-            (qt.QRegExp(r"#.*"), self.commentFormat),
-            (qt.QRegExp(r"@[A-Za-z_]+[A-Za-z0-9_]+"), self.decoratorFormat),
+            (
+                qt.QRegularExpression(r"\bdef\s+([A-Za-z_]+[A-Za-z0-9_]+)\s*\("),
+                self.defFormat,
+            ),
+            (
+                qt.QRegularExpression(r"\bclass\s+([A-Za-z_]+[A-Za-z0-9_]+)\s*\("),
+                self.defFormat,
+            ),
+            (qt.QRegularExpression(r"'.*'"), self.stringFormat),
+            (qt.QRegularExpression(r'".*"'), self.stringFormat),
+            (qt.QRegularExpression(r"#.*"), self.commentFormat),
+            (qt.QRegularExpression(r"@[A-Za-z_]+[A-Za-z0-9_]+"), self.decoratorFormat),
         ]
 
-        self.multilineStart = qt.QRegExp(r"(''')|" + r'(""")')
-        self.multilineEnd = qt.QRegExp(r"(''')|" + r'(""")')
+        self.multilineStart = qt.QRegularExpression(r"(''')|" + r'(""")')
+        self.multilineEnd = qt.QRegularExpression(r"(''')|" + r'(""")')
 
         super().__init__(parent)
 
     def highlightBlock(self, text):
         for pattern, format in self.rules:
-            exp = qt.QRegExp(pattern)
-            index = exp.indexIn(text)
+            exp = qt.QRegularExpression(pattern)
+            index = exp.match(text).capturedStart()
             while index >= 0:
-                length = exp.matchedLength()
+                length = exp.match(text).capturedLength()
                 if exp.captureCount() > 0:
                     self.setFormat(exp.pos(1), len(str(exp.cap(1))), format)
                 else:
                     self.setFormat(exp.pos(0), len(str(exp.cap(0))), format)
-                index = exp.indexIn(text, index + length)
+                index = exp.match(text, index + length).capturedStart()
 
         # Multi line strings
         start = self.multilineStart
@@ -219,9 +226,11 @@ class PythonConsole(qt.QPlainTextEdit, code.InteractiveConsole):
         self.historyInd = 0
 
         # prevent console errors to trigger error reporting & patch stdout, stderr
-        with patch("sys.excepthook", sys.__excepthook__), patch(
-            "sys.stdout", self
-        ), patch("sys.stderr", self):
+        with (
+            patch("sys.excepthook", sys.__excepthook__),
+            patch("sys.stdout", self),
+            patch("sys.stderr", self),
+        ):
             return code.InteractiveConsole.push(self, line)
 
     def setLine(self, line):
