@@ -339,7 +339,7 @@ class AxisOW(SuperviseOW, WidgetLongProcessing):
         )
         text += ", please select them from the `axis input` tab"
         msg.setText(text)
-        msg.exec_()
+        msg.exec()
 
     def _updateSettingsVals(self):
         # remove rp setting to the advantage of 'static_input'
