@@ -183,7 +183,7 @@ class NabuOW(WidgetLongProcessing, SuperviseOW):
             if self.__exec_for_ci is True:
                 self._ciExec()
             else:
-                if self.exec_():
+                if self.exec():
                     # for now The behavior for reprocessing is the sama as for processing
                     if hasattr(scan, "instance"):
                         self.process(scan.instance)
