@@ -28,6 +28,7 @@ from tomwer.core.process.reconstruction.nabu import utils as nabu_utils
 from tomwer.core.scan.scanbase import TomwerScanBase
 from tomwer.core.utils.char import BETA_CHAR, DELTA_CHAR
 from tomwer.core.utils.scanutils import format_output_location
+from tomwer.core.process.reconstruction.nabu.utils import update_nabu_config_for_tiff_3d
 from tomwer.core.volume.volumebase import TomwerVolumeBase
 from tomwer.core.volume.volumefactory import VolumeFactory
 from tomwer.gui.reconstruction.nabu.volume import NabuVolumeWindow
@@ -187,6 +188,7 @@ class NabuVolumeOW(WidgetLongProcessing, SuperviseOW):
         nabuSettingsWidget = self._nabuWidget._mainWidget._nabuSettingsWidget
         if nabuSettingsWidget.redefineNabuFileFormat():
             config["output"]["file_format"] = nabuSettingsWidget.getNabuFileFormat()
+            update_nabu_config_for_tiff_3d(config)
         # update output location if requested
         if nabuSettingsWidget.redefineOutputLocation():
             location = nabuSettingsWidget.getNabuOutputLocation()
