@@ -19,7 +19,10 @@ class WidgetLongProcessing:
                     info or "processing", text=None, shown=True
                 )
             else:
-                self.Processing.clear()
+                try:
+                    self.Processing.clear()
+                except Exception:
+                    pass
         except AttributeError:
             # in case we are on an orange version not having `Processing`
             pass
