@@ -6,6 +6,8 @@ import os
 import shutil
 import signal
 import sys
+import pkg_resources
+
 import silx
 from contextlib import closing
 from logging.handlers import RotatingFileHandler
@@ -30,8 +32,6 @@ from silx.gui import qt
 import tomwer.version
 from orangecanvas.preview import previewdialog, previewmodel
 from orangecanvas.application import examples as orange_examples
-import ewokscore
-import ewoksorange
 import tomoscan.version
 
 from .config import TomwerConfig, TomwerSplashScreen
@@ -347,6 +347,7 @@ class _OMain(ocMain):
         parser = super().argument_parser()
         parser.add_argument(
             "--use-opengl-plot",
+            "--opengl-backend",
             help="Use OpenGL for plots (instead of matplotlib)",
             action="store_true",
             default=False,
@@ -511,12 +512,10 @@ class AboutDialog(qt.QDialog):
                 sluurp.__version__ if has_sluurp else "not installed"
             ),
             ewokscore_version=escape(
-                ewokscore.__version__ if hasattr(ewokscore, "__version__") else "???"
+                pkg_resources.get_distribution("ewokscore").version
             ),
             ewoksorange_version=escape(
-                ewoksorange.__version__
-                if hasattr(ewoksorange, "__version__")
-                else "???"
+                pkg_resources.get_distribution("ewoksorange").version
             ),
         )
         text_label = qt.QLabel(text)
