@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from importlib.metadata import version as get_version
 import tomoscan.version
 
 import ewokscore
@@ -7,6 +8,7 @@ import ewoksorange
 import tomwer.version
 import sluurp
 
+
 try:
     import nxtomomill.version
 except ImportError:
@@ -40,8 +42,15 @@ def get_tomotools_stack_versions() -> dict[str, str]:
     if has_nxtomomill:
         stack["nxtomomill"] = nxtomomill.version.version
     stack["tomoscan"] = tomoscan.version.version
-    stack["ewokscore"] = ewokscore.__version__
-    stack["ewoksorange"] = ewoksorange.__version__
+    try:
+        stack["ewokscore"] = ewokscore.__version__
+    except AttributeError:
+        stack["ewokscore"] = get_version("ewokscore")
+
+    try:
+        stack["ewoksorange"] = ewoksorange.__version__
+    except AttributeError:
+        stack["ewoksorange"] = get_version("ewoksorange")
     stack["sluurp"] = sluurp.__version__
 
     return stack
