@@ -43,6 +43,7 @@ def main(argv):
     parser.add_argument("--second-entry", default=None, help="Second entry")
     parser.add_argument(
         "--use-opengl-plot",
+        "--opengl-backend",
         help="Use OpenGL for plots (instead of matplotlib)",
         action="store_true",
         default=False,
@@ -99,7 +100,7 @@ def main(argv):
     widget.setWindowIcon(icons.getQIcon("tomwer"))
     splash.finish(widget)
     widget.show()
-    app.exec_()
+    app.exec()
 
 
 if __name__ == "__main__":
