@@ -102,7 +102,7 @@ def main(argv):
     widget.setWindowIcon(icons.getQIcon("tomwer"))
     splash.finish(widget)
     widget.show()
-    app.exec_()
+    app.exec()
 
 
 if __name__ == "__main__":
