@@ -145,7 +145,7 @@ class SAAxisWindow(_SAAxisWindow):
                 "from the `axis input` tab"
             )
             msg.setText(text)
-            msg.exec_()
+            msg.exec()
             return None
         else:
             self.setEstimatedCorPosition(
@@ -194,6 +194,7 @@ def main(argv):
     )
     parser.add_argument(
         "--use-opengl-plot",
+        "--opengl-backend",
         help="Use OpenGL for plots (instead of matplotlib)",
         action="store_true",
         default=False,
@@ -259,7 +260,7 @@ def main(argv):
     window.show()
     qt.QApplication.restoreOverrideCursor()
     app.aboutToQuit.connect(window.stop)
-    exit(app.exec_())
+    exit(app.exec())
 
 
 def getinputinfo():
