@@ -231,7 +231,7 @@ class SADeltaBetaWindow(_SADeltaBetaWindow):
                 "from the `axis input` tab"
             )
             msg.setText(text)
-            msg.exec_()
+            msg.exec()
             return None
         else:
             self.setRelativeCorPosition(
@@ -279,6 +279,7 @@ def main(argv):
     )
     parser.add_argument(
         "--use-opengl-plot",
+        "--opengl-backend",
         help="Use OpenGL for plots (instead of matplotlib)",
         action="store_true",
         default=False,
@@ -333,7 +334,7 @@ def main(argv):
     window.show()
     qt.QApplication.restoreOverrideCursor()
     app.aboutToQuit.connect(window.stop)
-    app.exec_()
+    app.exec()
 
 
 def getinputinfo():
