@@ -94,7 +94,7 @@ def main(argv):
     splash.finish(dialog)
 
     qt.QApplication.restoreOverrideCursor()
-    app.exec_()
+    app.exec()
 
 
 def getinputinfo():
