@@ -113,7 +113,7 @@ def main(argv):
     splash.finish(window)
     window.show()
     qt.QApplication.restoreOverrideCursor()
-    app.exec_()
+    app.exec()
 
 
 def getinputinfo():
