@@ -46,6 +46,7 @@ def main(argv):
     )
     parser.add_argument(
         "--use-opengl-plot",
+        "--opengl-backend",
         help="Use OpenGL for plots (instead of matplotlib)",
         action="store_true",
         default=False,
@@ -88,7 +89,7 @@ def main(argv):
 
     splash.finish(widget)
     widget.show()
-    app.exec_()
+    app.exec()
 
 
 if __name__ == "__main__":
