@@ -35,6 +35,7 @@ def main(argv):
     )
     parser.add_argument(
         "--use-opengl-plot",
+        "--opengl-backend",
         help="Use OpenGL for plots (instead of matplotlib)",
         action="store_true",
         default=False,
@@ -83,7 +84,7 @@ def main(argv):
 
     qt.QApplication.restoreOverrideCursor()
     app.aboutToQuit.connect(window.close)
-    exit(app.exec_())
+    exit(app.exec())
 
 
 def getinputinfo():
