@@ -66,6 +66,7 @@ def main(argv):
     )
     parser.add_argument(
         "--use-opengl-plot",
+        "--opengl-backend",
         help="Use OpenGL for plots (instead of matplotlib)",
         action="store_true",
         default=False,
@@ -118,7 +119,7 @@ def main(argv):
     widget.setWindowIcon(icons.getQIcon("tomwer"))
     splash.finish(widget)
     widget.show()
-    app.exec_()
+    app.exec()
 
 
 if __name__ == "__main__":
