@@ -79,6 +79,14 @@ class MainWidget(qt.QTabWidget):
             }
         )
 
+        style = qt.QApplication.style()
+        help_icon = style.standardIcon(qt.QStyle.SP_TitleBarContextHelpButton)
+
+        self._helpButton = qt.QPushButton(help_icon, "help")
+        self._slurmConfig.layout().addWidget(
+            self._helpButton, 99, 0, qt.Qt.AlignLeft, qt.Qt.AlignTop
+        )
+
         self._stitchingConfigWindow.setCallbackToGetSlurmConfig(
             self._slurmConfig.getConfiguration
         )
@@ -99,6 +107,9 @@ class MainWidget(qt.QTabWidget):
         # set up
         self._slurmConfig.setNWorkers(self.DEFAULT_NB_WORKERS)
 
+        # connect signal / slot
+        self._helpButton.released.connect(self._showSlurmSettingHelpForStitching)
+
     def close(self):
         self._stitchingConfigWindow.close()
         # requested for the waiting plot update
@@ -124,6 +135,37 @@ class MainWidget(qt.QTabWidget):
     def getClusterConfig(self) -> dict:
         return self._slurmConfig.getConfiguration()
 
+    def _showSlurmSettingHelpForStitching(self):
+        msg = qt.QMessageBox()
+        msg.setWindowTitle("Help")
+        msg.setText(
+            """
+            <b>Stitching Process Hints:</b>
+            <ul>
+            <li>
+                <b>Processing Mode:</b> Stitching is performed using <b>CPU only</b> (GPU acceleration is not supported).
+            </li>
+            <li>
+                <b>Memory Management:</b>
+                <ul>
+                <li>Stitching is processed in <b>chunks</b>, based on available memory.</li>
+                <li>At least <b>one slice from each element</b> must be loaded into memory at all times.</li>
+                </ul>
+            </li>
+            <li>
+                <b>Job Parallelization:</b>
+                <ul>
+                <li>The stitching task is split into <b><code>n</code> parallel jobs</b> (where <code>n</code> = number of jobs).</li>
+                <li>For optimal performance, we recommend each job processes a "<b>reasonable</b>" data size (e.g., <b>30 GB to 100 GB</b>).</li>
+                </ul>
+            </li>
+            </ul>
+            See <a href='https://tomwer.readthedocs.io/en/stable/applications/z_stitching.html'> application documentation</a> and <a href='https://tomwer.readthedocs.io/en/stable/tutorials/notebooks/standalone_apps/z_stitching.html'> stitching tutorial</a> for more details.
+            """
+        )
+        msg.setIcon(qt.QMessageBox.Information)
+        msg.exec()
+
     # expose API
     def addTomoObj(self, *args, **kwargs):
         self._stitchingConfigWindow.addTomoObj(*args, **kwargs)
@@ -506,6 +548,7 @@ def main(argv, stitcher_name: str, stitching_axis: int, logger):
     )
     parser.add_argument(
         "--use-opengl-plot",
+        "--opengl-backend",
         help="Use OpenGL for plots (instead of matplotlib)",
         action="store_true",
         default=False,
@@ -589,7 +632,7 @@ def main(argv, stitcher_name: str, stitching_axis: int, logger):
 
     window.setAttribute(qt.Qt.WA_DeleteOnClose)
     splash.finish(window)
-    exit(app.exec_())
+    exit(app.exec())
 
 
 def sigintHandler(*args):
