@@ -8,9 +8,7 @@ import argparse
 import sys
 from signal import SIGKILL, SIGTERM
 
-from tomwer.core.process.control.datalistener.rpcserver import (
-    send_signal_to_local_rpc_servers,
-)
+from tomwer.core.utils.process import send_signal_to_local_rpc_servers
 from tomwer.core.settings import JSON_RPC_PORT
 
 
