@@ -53,7 +53,14 @@ class FutureSupervisorTask(
                     for vol_id in tomo_obj.latest_vol_reconstructions
                 ]
             )
-            self.outputs.volume = None
+            if len(tomo_obj.latest_vol_reconstructions) > 0:
+                # at the moment we expect at most one volume from a scan.
+                # If it changes we will need to replace `volume` by `volumes`
+                self.outputs.volume = VolumeFactory.create_tomo_object_from_identifier(
+                    tomo_obj.latest_vol_reconstructions[0]
+                )
+            else:
+                self.outputs.volume = None
         elif isinstance(tomo_obj, TomwerVolumeBase):
             self.outputs.volume = tomo_obj
             self.outputs.data_portal_processed_datasets = ()
