@@ -1,5 +1,5 @@
 import numpy
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 
 class Binning(_Enum):
@@ -18,7 +18,7 @@ class Binning(_Enum):
             raise TypeError("data should be a numpy array")
         if not data.ndim == 2:
             raise ValueError("data is expected to be 2d")
-        binning = Binning.from_value(binning)
+        binning = Binning(binning)
         if binning is Binning.ONE_BY_ONE:
             return data
         elif binning is Binning.TWO_BY_TWO:
