@@ -3,6 +3,7 @@ from __future__ import annotations
 import os
 import numpy
 import logging
+import pathlib
 from PIL import Image
 from silx.io.url import DataUrl
 
@@ -37,7 +38,8 @@ class DracDatasetBase:
         :param data_dir: directory containing processed data
         :param tomo_obj: tomwer object referee for the processing
         """
-        self._data_dir = filter_esrf_mounting_points(data_dir)
+        data_dir = pathlib.Path(data_dir).resolve()
+        self._data_dir = filter_esrf_mounting_points(str(data_dir))
         self._tomo_obj = tomo_obj
         self._gallery_file_binning = Binning.FOUR_BY_FOUR
         self._gallery_output_format = OutputFormat.PNG
