@@ -1,4 +1,4 @@
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 
 PROPOSAL_GALLERY_DIR_NAME = "GALLERY"
