@@ -49,9 +49,7 @@ def change_image_key_control(scan: NXtomoScan, config: dict) -> TomwerScanBase:
             modifications = {}
 
     image_keys_set = set(modifications.values())
-    image_keys_set = set(
-        [ImageKey.from_value(image_key) for image_key in image_keys_set]
-    )
+    image_keys_set = set([ImageKey(image_key) for image_key in image_keys_set])
     for image_key_type in image_keys_set:
         frame_indexes_dict = dict(
             filter(lambda item: item[1] is image_key_type, modifications.items())
@@ -65,7 +63,7 @@ def change_image_key_control(scan: NXtomoScan, config: dict) -> TomwerScanBase:
             image_key_control_value=image_key_type.value,
             logger=_logger,
         )
-    scan.clear_frames_caches()
+    scan.clear_frames_cache()
     return scan
 
 
@@ -181,8 +179,8 @@ class ImageKeyUpgraderTask(
         """
         retrieve frame indices to be updated
         """
-        from_image_key = ImageKey.from_value(from_image_key)
-        to_image_key = ImageKey.from_value(to_image_key)
+        from_image_key = ImageKey(from_image_key)
+        to_image_key = ImageKey(to_image_key)
 
         config = {}
         for i_frame, frame in enumerate(scan.frames):
