@@ -15,8 +15,8 @@ from tomoscan.io import HDF5File
 from nxtomo.paths.nxtomo import get_paths as get_nexus_paths
 from nxtomo.nxobject.nxtransformations import NXtransformations
 from nxtomo.utils.transformation import (
+    DetXFlipTransformation,
     DetYFlipTransformation,
-    DetZFlipTransformation,
 )
 
 from tomwer.core.process.task import Task
@@ -33,12 +33,16 @@ class NXtomoEditorKeys:
     """namespace to store all keys used by the nxtomo editor"""
 
     ENERGY = "instrument.beam.energy"
-    X_PIXEL_SIZE = "instrument.detector.x_pixel_size"
-    Y_PIXEL_SIZE = "instrument.detector.y_pixel_size"
+    DETECTOR_X_PIXEL_SIZE = "instrument.detector.x_pixel_size"
+    DETECTOR_Y_PIXEL_SIZE = "instrument.detector.y_pixel_size"
     SAMPLE_DETECTOR_DISTANCE = "instrument.detector.distance"
+    SAMPLE_SOURCE_DISTANCE = "instrument.source.distance"
+    SAMPLE_X_PIXEL_SIZE = "sample.x_pixel_size"
+    SAMPLE_Y_PIXEL_SIZE = "sample.y_pixel_size"
+    PROPAGATION_DISTANCE = "sample.propagation_distance"
     FIELD_OF_VIEW = "instrument.detector.field_of_view"
-    X_FLIPPED = "instrument.detector.x_flipped"
-    Y_FLIPPED = "instrument.detector.y_flipped"
+    LR_FLIPPED = "instrument.detector.lr_flipped"
+    UD_FLIPPED = "instrument.detector.ud_flipped"
     X_TRANSLATION = "sample.x_translation"
     Y_TRANSLATION = "sample.y_translation"
     Z_TRANSLATION = "sample.z_translation"
@@ -53,15 +57,6 @@ class NXtomoEditorTask(
     task to edit a couple of field of a NXtomo
     """
 
-    Y_FLIP_MATRIX = DetYFlipTransformation(flip=True).as_matrix()
-    # up-down flip matrix
-    Z_FLIP_MATRIX = DetZFlipTransformation(flip=True).as_matrix()
-    # left-right flip matrix
-    Y_AND_Z_flip_MATRIX = numpy.matmul(
-        Y_FLIP_MATRIX,
-        Z_FLIP_MATRIX,
-    )
-
     def run(self):
         scan = self.inputs.data
         if scan is None:
@@ -83,8 +78,8 @@ class NXtomoEditorTask(
             nexus_version=scan.nexus_version, n_frames=n_frames
         )
 
-        x_flip = configuration.pop(NXtomoEditorKeys.X_FLIPPED, None)
-        y_flip = configuration.pop(NXtomoEditorKeys.Y_FLIPPED, None)
+        lr_flip = configuration.pop(NXtomoEditorKeys.LR_FLIPPED, None)
+        ud_flip = configuration.pop(NXtomoEditorKeys.UD_FLIPPED, None)
 
         with HDF5File(scan.master_file, mode="a") as h5f:
             entry = h5f[scan.entry]
@@ -103,12 +98,16 @@ class NXtomoEditorTask(
                 )
 
             # solve NXtransformations
-            if x_flip is not None or y_flip is not None:
+            if lr_flip is not None or ud_flip is not None:
                 nx_transformations, detector_transformation_path = (
                     self.get_detector_transformations(
                         scan_entry=scan.entry,
-                        x_flip=x_flip if x_flip is not None else scan.x_flipped,
-                        y_flip=y_flip if y_flip is not None else scan.y_flipped,
+                        lr_flip=(
+                            lr_flip if lr_flip is not None else scan.detector_is_lr_flip
+                        ),
+                        ud_flip=(
+                            ud_flip if ud_flip is not None else scan.detector_is_ud_flip
+                        ),
                         nexus_version=scan.nexus_version,
                     )
                 )
@@ -125,13 +124,13 @@ class NXtomoEditorTask(
                 overwrite=True,
             )
         # clear caches to make sure all modifications will be considered
-        scan.clear_caches()
-        scan.clear_frames_caches()
+        scan.clear_cache()
+        scan.clear_frames_cache()
         self.outputs.data = scan
 
     @staticmethod
     def get_detector_transformations(
-        scan_entry: str, x_flip: bool, y_flip: bool, nexus_version: float | None
+        scan_entry: str, lr_flip: bool, ud_flip: bool, nexus_version: float | None
     ) -> dict:
         nexus_paths = get_nexus_paths(nexus_version)
         if nexus_paths.nx_detector_paths.NX_TRANSFORMATIONS is None:
@@ -139,11 +138,11 @@ class NXtomoEditorTask(
             _logger.debug(
                 "Old version of NXtomo found. No information about transformation will be saved"
             )
-            return
+            return None, None
 
         nx_transformations = NXtransformations()
-        nx_transformations.add_transformation(DetYFlipTransformation(flip=y_flip))
-        nx_transformations.add_transformation(DetZFlipTransformation(flip=x_flip))
+        nx_transformations.add_transformation(DetXFlipTransformation(flip=ud_flip))
+        nx_transformations.add_transformation(DetYFlipTransformation(flip=lr_flip))
 
         detector_transformation_path = "/".join(
             (
@@ -239,7 +238,7 @@ class NXtomoEditorTask(
         """
         nexus_paths = get_nexus_paths(nexus_version)
 
-        return {
+        mapping = {
             # energy
             NXtomoEditorKeys.ENERGY: _EditorFieldInfo(
                 nexus_path=nexus_paths.ENERGY_PATH,
@@ -248,25 +247,17 @@ class NXtomoEditorTask(
                 name="energy",
                 n_value=1,
             ),
-            # x pixel size
-            NXtomoEditorKeys.X_PIXEL_SIZE: _EditorFieldInfo(
-                nexus_path=nexus_paths.X_PIXEL_SIZE_PATH,
-                expected_type=float,
-                units="m",
-                name="x pixel size",
-                n_value=1,
-            ),
-            # y pixel size
-            NXtomoEditorKeys.Y_PIXEL_SIZE: _EditorFieldInfo(
-                nexus_path=nexus_paths.Y_PIXEL_SIZE_PATH,
-                expected_type=float,
-                units="m",
-                name="y pixel size",
-                n_value=1,
-            ),
             # sample / detector distance
             NXtomoEditorKeys.SAMPLE_DETECTOR_DISTANCE: _EditorFieldInfo(
-                nexus_path=nexus_paths.DISTANCE_PATH,
+                nexus_path=nexus_paths.SAMPLE_DETECTOR_DISTANCE_PATH,
+                expected_type=float,
+                units="m",
+                name="sample detector distance",
+                n_value=1,
+            ),
+            # sample / source distance
+            NXtomoEditorKeys.SAMPLE_SOURCE_DISTANCE: _EditorFieldInfo(
+                nexus_path=nexus_paths.SAMPLE_SOURCE_DISTANCE_PATH,
                 expected_type=float,
                 units="m",
                 name="sample detector distance",
@@ -304,4 +295,46 @@ class NXtomoEditorTask(
                 name="z translation",
                 n_value=n_frames,
             ),
+            # detector x pixel size
+            NXtomoEditorKeys.DETECTOR_X_PIXEL_SIZE: _EditorFieldInfo(
+                nexus_path=nexus_paths.DETECTOR_X_PIXEL_SIZE_PATH,
+                expected_type=float,
+                units="m",
+                name="detector x pixel size",
+                n_value=1,
+            ),
+            # detector y pixel size
+            NXtomoEditorKeys.DETECTOR_Y_PIXEL_SIZE: _EditorFieldInfo(
+                nexus_path=nexus_paths.DETECTOR_Y_PIXEL_SIZE_PATH,
+                expected_type=float,
+                units="m",
+                name="detector y pixel size",
+                n_value=1,
+            ),
+            # sample x pixel size
+            NXtomoEditorKeys.SAMPLE_X_PIXEL_SIZE: _EditorFieldInfo(
+                nexus_path=nexus_paths.SAMPLE_X_PIXEL_SIZE_PATH,
+                expected_type=float,
+                units="m",
+                name="sample x pixel size",
+                n_value=1,
+            ),
+            # sample y pixel size
+            NXtomoEditorKeys.SAMPLE_Y_PIXEL_SIZE: _EditorFieldInfo(
+                nexus_path=nexus_paths.SAMPLE_Y_PIXEL_SIZE_PATH,
+                expected_type=float,
+                units="m",
+                name="sample y pixel size",
+                n_value=1,
+            ),
+            # propagation distance
+            NXtomoEditorKeys.PROPAGATION_DISTANCE: _EditorFieldInfo(
+                nexus_path=nexus_paths.PROPAGATION_DISTANCE,
+                expected_type=float,
+                units="m",
+                name="propagation distance",
+                n_value=1,
+            ),
         }
+
+        return mapping
