@@ -1,6 +1,6 @@
 # coding: utf-8
 
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 
 class CorAngleMode(_Enum):
@@ -18,4 +18,4 @@ class CorAngleMode(_Enum):
         elif value == 2:
             return CorAngleMode.manual_selection
         else:
-            return super().from_value(value=value)
+            return CorAngleMode(value=value)
