@@ -226,18 +226,27 @@ class AxisRP:
         """Mode used for defining the COR (center of rotation)"""
         self.__relative_value = None
         """Value of the center of rotation in [0; image_width].
-        None is not processing"""
+        None is not processing.
+        This value is on the *raw* frames referential as expected by nabu. It means it doesn't take into account
+        possible detector flips.
+        """
         self.__absolute_value = None
-        """Value of the center of rotation in [-image_width/2; image_width/2].
-        None is not processing"""
+        """
+        Value of the center of rotation in [-image_width/2; image_width/2].
+        None is not processing.
+        This value is on the *raw* frames referential as expected by nabu. It means it doesn't take into account
+        possible detector flips.
+        """
         self.__angle_mode = CorAngleMode.use_0_180
         """Angle to use for radios"""
         self.__x_rotation_axis_pixel_position = None
-        """rotation axis position obtained from motor"""
+        """rotation axis position obtained from motor. In the **raw** frame referential."""
         self.__x_rotation_axis_pos_px_offset = 0.0
         """motor offset to be used to compute the 'estimated_cor' from 'x_rotation_axis_pixel_position'"""
         self.__estimated_cor = 0.0
-        """Estimated position of the center of rotation. Given by the user or computed from 'x_rotation_axis_pixel_position' and 'pixel_offset'"""
+        """Estimated position of the center of rotation. Given by the user or computed from 'x_rotation_axis_pixel_position' and 'pixel_offset'.
+        In the **raw** frame referential.
+        """
         self.__axis_url_1 = AxisResource(url=None)
         """first data url to use for axis cor calculation"""
         self.__axis_url_2 = AxisResource(url=None)
