@@ -3,7 +3,6 @@ from __future__ import annotations
 
 import enum
 
-from silx.utils.enum import Enum as _Enum
 from tomoscan.framereducer.method import ReduceMethod
 
 from tomwer.core.process.reconstruction.darkref.settings import (
@@ -17,7 +16,7 @@ from tomwer.core.utils.deprecation import deprecated
 # TODO: those classes (when, method) should be linked / embedded in the DarkRef
 # method
 @enum.unique
-class When(_Enum):
+class When(enum.Enum):
     never = (0,)
     before = (1,)
     after = (2,)
@@ -35,7 +34,7 @@ def _from_value_reduce_method_backward_compatibility(value) -> ReduceMethod:
     elif value in ("last", 11, (11,)):
         return ReduceMethod.FIRST
     else:
-        return ReduceMethod.from_value(value)
+        return ReduceMethod(value)
 
 
 class DKRFRP(_ReconsParam):
