@@ -10,6 +10,8 @@ import logging
 import os
 
 import numpy
+import pathlib
+
 from nabu.io.cast_volume import RESCALE_MAX_PERCENTILE, RESCALE_MIN_PERCENTILE
 from nabu.io.cast_volume import cast_volume as _nabu_cast_volume
 from nabu.io.cast_volume import get_default_output_volume
@@ -18,6 +20,7 @@ from processview.core.superviseprocess import SuperviseProcess
 from sluurp.executor import submit as submit_to_slurm_cluster
 from sluurp.job import SBatchScriptJob
 from tomoscan.volumebase import VolumeBase
+from tomoscan.utils.io import filter_esrf_mounting_points
 
 from tomwer.core.cluster.cluster import SlurmClusterConfiguration
 from tomwer.core.futureobject import FutureTomwerObject
@@ -235,10 +238,13 @@ class CastVolumeTask(
 
             script_name = get_slurm_script_name(prefix="nabu_cast")
             if scan is not None:
-                working_directory = scan.working_directory
-                script_path = os.path.join(scan.path, "slurm_scripts", script_name)
+                working_directory = scan.working_directory.resolve()
+                script_path = os.path.join(
+                    scan.resolved_path, "slurm_scripts", script_name
+                )
             else:
                 working_directory = os.path.dirname(input_volume.data_url.file_path())
+                working_directory = str(pathlib.Path(working_directory).resolve())
                 script_path = os.path.join(
                     working_directory, "slurm_scripts", script_name
                 )
@@ -249,9 +255,9 @@ class CastVolumeTask(
             job = SBatchScriptJob(
                 slurm_config=self._cluster_config,
                 script=(get_command(),),
-                script_path=script_path,
+                script_path=filter_esrf_mounting_points(script_path),
                 clean_script=False,
-                working_directory=working_directory,
+                working_directory=filter_esrf_mounting_points(working_directory),
             )
             future_slurm_job = submit_to_slurm_cluster(job)
             if scan is not None:
