@@ -21,6 +21,7 @@ from sluurp.job import SBatchScriptJob
 from tomoscan.io import HDF5File
 from tomoscan.normalization import Method as INormMethod
 from tomoscan.identifier import VolumeIdentifier
+from tomoscan.utils.io import filter_esrf_mounting_points
 
 from tomwer.core.process.reconstruction.nabu.plane import NabuPlane
 from tomwer.core.cluster.cluster import SlurmClusterConfiguration
@@ -453,9 +454,13 @@ class _NabuBaseReconstructor:
             script=(
                 f"python3 -m {settings.NABU_FULL_FIELD_APP_PATH} '{conf_file}' --gpu_mem_fraction {gpu_mem_fraction} --cpu_mem_fraction {cpu_mem_fraction}",
             ),
-            script_path=os.path.join(self.scan.path, "slurm_scripts", script_name),
+            script_path=filter_esrf_mounting_points(
+                os.path.join(self.scan.resolved_path, "slurm_scripts", script_name)
+            ),
             clean_script=False,
-            working_directory=self.scan.working_directory,
+            working_directory=filter_esrf_mounting_points(
+                str(self.scan.working_directory.resolve())
+            ),
         )
         future_slurm_job = submit_to_slurm_cluster(job)
 
