@@ -32,6 +32,8 @@ from processview.core.manager.manager import ProcessManager
 from sluurp.job import SBatchScriptJob
 from sluurp.executor import submit as submit_to_slurm_cluster
 
+from tomoscan.utils.io import filter_esrf_mounting_points
+
 from tomwer.core.futureobject import FutureTomwerObject
 from tomwer.core.process.reconstruction.nabu.nabuslices import (
     SingleSliceRunner,
@@ -632,9 +634,13 @@ class _ReconstructorMultiCor(_NabuBaseReconstructor):
             script=(
                 f"python3 -m {settings.NABU_MULTICOR_PATH} {conf_file} {slice_index} {cor_in_nabu_ref}",
             ),
-            script_path=os.path.join(self.scan.path, "slurm_scripts", script_name),
+            script_path=filter_esrf_mounting_points(
+                os.path.join(self.scan.resolved_path, "slurm_scripts", script_name)
+            ),
             clean_script=False,
-            working_directory=self.scan.working_directory,
+            working_directory=filter_esrf_mounting_points(
+                str(self.scan.working_directory.resolve())
+            ),
         )
         future_slurm_job = submit_to_slurm_cluster(job)
 
