@@ -15,6 +15,10 @@ from processview.core.manager.manager import ProcessManager, DatasetState
 from tomwer.core.futureobject import FutureTomwerObject
 from tomwer.core.utils.scanutils import data_identifier_to_scan
 from tomwer.core.utils.slurm import is_slurm_available
+from tomwer.core.process.reconstruction.nabu.utils import (
+    update_nabu_config_for_tiff_3d,
+    from_nabu_config_to_file_format,
+)
 from tomwer.core.process.reconstruction.nabu.plane import NabuPlane
 from tomwer.core.process.reconstruction.nabu.utils import slice_index_to_int
 from tomwer.core.process.reconstruction.utils.cor import relative_pos_to_absolute
@@ -639,6 +643,8 @@ class SingleSliceRunner(_NabuBaseReconstructor):
         conf_file = os.path.join(cfg_folder, name)
 
         _logger.info(f"{self.scan}: create {conf_file}")
+        file_format = config["output"]["file_format"]
+        update_nabu_config_for_tiff_3d(config)
         # add some tomwer metadata and save the configuration
         # note: for now the section is ignored by nabu but shouldn't stay that way
         with utils.TomwerInfo(config) as config_to_dump:
@@ -655,7 +661,7 @@ class SingleSliceRunner(_NabuBaseReconstructor):
                     config_to_dump=config_to_dump,
                     config_file=conf_file,
                     info="nabu slice reconstruction",
-                    file_format=config_to_dump["output"]["file_format"],
+                    file_format=file_format,
                     process_name=self.process_name,
                 ),
             ]
@@ -679,7 +685,7 @@ class SingleSliceRunner(_NabuBaseReconstructor):
                         recons_urls = self.f_partial()
                         self.scan.add_latest_reconstructions(recons_urls)
 
-            file_format = config_to_dump["output"]["file_format"]
+            file_format = from_nabu_config_to_file_format(config_to_dump)
             callback = functools.partial(
                 utils.get_recons_volume_identifier,
                 file_prefix=config_to_dump["output"]["file_prefix"],
