@@ -20,6 +20,10 @@ from tomwer.core.utils.deprecation import deprecated_warning
 from tomwer.core.cluster.cluster import SlurmClusterConfiguration
 from tomwer.core.futureobject import FutureTomwerObject
 from tomwer.core.process.reconstruction.nabu.plane import NabuPlane
+from tomwer.core.process.reconstruction.nabu.utils import (
+    from_nabu_config_to_file_format,
+    update_nabu_config_for_tiff_3d,
+)
 from tomwer.core.process.task import Task
 from tomwer.core.process.drac.processeddataset import DracReconstructedVolumeDataset
 from tomwer.core.scan.edfscan import EDFTomoScan
@@ -234,6 +238,8 @@ class VolumeRunner(_NabuBaseReconstructor):
         # make sure output location exists
         os.makedirs(config_slices["output"]["location"], exist_ok=True)
 
+        file_format = config_slices["output"]["file_format"]
+        update_nabu_config_for_tiff_3d(config_slices)
         # add some tomwer metadata and save the configuration
         # note: for now the section is ignored by nabu but shouldn't stay that way
         with utils.TomwerInfo(config_slices) as config_to_dump:
@@ -249,7 +255,7 @@ class VolumeRunner(_NabuBaseReconstructor):
                         config_to_dump=config_to_dump,
                         config_file=conf_file,
                         info="nabu volume reconstruction",
-                        file_format=config_slices["output"]["file_format"],
+                        file_format=file_format,
                         process_name=self.process_name,
                     )
                 ]
@@ -272,7 +278,8 @@ class VolumeRunner(_NabuBaseReconstructor):
                     recons_identifiers = self.f_partial()
                     self.scan.add_latest_vol_reconstructions(recons_identifiers)
 
-        file_format = config_to_dump["output"]["file_format"]
+        file_format = from_nabu_config_to_file_format(config_to_dump)
+
         callback = functools.partial(
             utils.get_recons_volume_identifier,
             file_prefix=config_to_dump["output"]["file_prefix"],
