@@ -1,6 +1,6 @@
 """Define nabu Axis"""
 
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 
 class NabuPlane(_Enum):
@@ -16,4 +16,4 @@ class NabuPlane(_Enum):
             return NabuPlane.XZ
         elif value == 2:
             return NabuPlane.YZ
-        return super().from_value(value=value)
+        return NabuPlane(value=value)
