@@ -1,6 +1,6 @@
 # coding: utf-8
 
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 
 class Target(_Enum):
