@@ -10,6 +10,7 @@ from tomwer.core.scan.edfscan import EDFTomoScan
 from tomwer.core.scan.nxtomoscan import NXtomoScan
 from tomwer.core.volume.edfvolume import EDFVolume
 from tomwer.core.volume.hdf5volume import HDF5Volume
+from tomoscan.esrf.volume.jp2kvolume import has_minimal_openjpeg
 
 _scans = (
     NXtomoScan(
@@ -82,6 +83,8 @@ def test_get_recons_volume_identifier(scan, axis):
         == "jp2k:volume:/this/is/a/test?file_prefix=volume_recslice"
     )
 
+    if not has_minimal_openjpeg:
+        pytest.skip("Missing minimal opengl version")
     # check tiff slice reconstructions
     id_rec_vols = get_recons_volume_identifier(
         file_prefix="volume_rec",
