@@ -4,7 +4,7 @@ material for radio and sinogram normalization
 """
 from __future__ import annotations
 
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 from tomoscan.normalization import Method
 
 
@@ -39,7 +39,7 @@ class _DatasetInfos:
 
     @scope.setter
     def scope(self, scope: str | _DatasetScope):
-        self._scope = _DatasetScope.from_value(scope)
+        self._scope = _DatasetScope(scope)
 
     @property
     def file_path(self):
@@ -86,7 +86,7 @@ class SinoNormalizationParams:
     def method(self, method: str | Method | None):
         if method is None:
             method = Method.NONE
-        self._method = Method.from_value(method)
+        self._method = Method(method)
 
     @property
     def source(self):
@@ -96,7 +96,7 @@ class SinoNormalizationParams:
     def source(self, source):
         if source is None:
             source = _ValueSource.NONE
-        self._source = _ValueSource.from_value(source)
+        self._source = _ValueSource(source)
 
     @property
     def extra_infos(self):
