@@ -60,9 +60,9 @@ def get_output_folder_from_scan(
         location = os.path.join(scan.path, processed_data_folder_name)
         location_cfg_files = location
         if file_format in (
-            NabuOutputFileFormat.EDF.value,
-            NabuOutputFileFormat.TIFF.value,
-            NabuOutputFileFormat.JP2K.value,
+            NabuOutputFileFormat.EDF,
+            NabuOutputFileFormat.TIFF,
+            NabuOutputFileFormat.JP2K,
         ):  # if user specify the location
             location = "/".join([location, file_basename])
         if output_mode is ProcessDataOutputDirMode.PROCESSED_DATA_FOLDER:
