@@ -39,6 +39,7 @@ from tomwer.core.scan.scanfactory import ScanFactory
 from tomwer.core.utils import logconfig
 from tomwer.core.utils.scanutils import data_identifier_to_scan
 from tomwer.core.utils.slurm import is_slurm_available
+from tomwer.core.process.reconstruction.nabu.utils import update_nabu_config_for_tiff_3d
 
 from tomwer.io.utils.h5pyutils import EntryReader
 from tomwer.core.volume.volumefactory import VolumeFactory
@@ -226,6 +227,8 @@ class SAAxisTask(
             nabu_configuration["output"] = {}
         nabu_configuration["output"]["location"] = output_dir
         nabu_configuration["output"]["file_format"] = file_format
+        update_nabu_config_for_tiff_3d(nabu_configuration)
+
         # handle resources section
         nabu_configuration["resources"] = nabu_configuration.get("resources", {})
         nabu_configuration["resources"]["method"] = "local"
