@@ -162,12 +162,9 @@ class StitchingPostProcAggregation(_StitchingPostProcAggregation):
 
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
-        print("creates StitchingPostProcAggregation")
 
         if isinstance(self.stitching_config, dict):
-            stitching_type = StitchingType.from_value(
-                self.stitching_config["stitching"]["type"]
-            )
+            stitching_type = StitchingType(self.stitching_config["stitching"]["type"])
             if stitching_type is StitchingType.Z_PREPROC:
                 self._stitching_config = PreProcessedZStitchingConfiguration.from_dict(
                     self.stitching_config
