@@ -9,6 +9,7 @@ from glob import glob
 from math import ceil
 import pathlib
 from datetime import datetime
+from pathlib import Path
 
 import fabio
 import numpy
@@ -115,8 +116,11 @@ class EDFTomoScan(_tsEDFTomoScan, TomwerScanBase):
             return os.path.isfile(info_file)
 
     @property
-    def working_directory(self):
-        return self.path
+    def working_directory(self) -> None | Path:
+        if self.path is None:
+            return None
+        else:
+            return Path(self.path)
 
     @staticmethod
     def from_identifier(identifier):
