@@ -8,6 +8,7 @@ import os
 import pathlib
 from datetime import datetime
 from urllib.parse import urlparse
+from pathlib import Path
 
 import h5py
 from processview.core.dataset import DatasetIdentifier
@@ -117,11 +118,11 @@ class NXtomoScan(_tsNXtomoScan, TomwerScanBase):
             self.set_reduced_flats(reduced_flats, flats_infos=metadata)
 
     @property
-    def working_directory(self):
+    def working_directory(self) -> None | Path:
         if self.master_file is None:
             return None
         else:
-            return os.path.abspath(os.path.dirname(self.master_file))
+            return Path(os.path.dirname(self.master_file)).absolute()
 
     @property
     def helical(self):
@@ -178,9 +179,9 @@ class NXtomoScan(_tsNXtomoScan, TomwerScanBase):
         else:
             return os.path.exists(master_file + ".h5")
 
-    def clear_caches(self):
-        _tsNXtomoScan.clear_caches(self)
-        TomwerScanBase.clear_caches(self)
+    def clear_cache(self):
+        _tsNXtomoScan.clear_cache(self)
+        TomwerScanBase.clear_cache(self)
 
     def is_abort(self, src_pattern, dest_pattern):
         """
@@ -427,7 +428,9 @@ class NXtomoScan(_tsNXtomoScan, TomwerScanBase):
             )
         return {
             "hdf5_entry": self.entry,
-            "location": os.path.basename(self.master_file),
+            "location": filter_esrf_mounting_points(
+                str(pathlib.Path(self.master_file).resolve())
+            ),
             "binning": binning,
             "binning_z": binning_z,
             "projections_subsampling": proj_subsampling,
@@ -476,7 +479,9 @@ class NXtomoScan(_tsNXtomoScan, TomwerScanBase):
                 bliss_raw_data_files[0] if len(bliss_raw_data_files) > 0 else None
             )
             if bliss_raw_data_file is not None:
-                bliss_raw_data_file = filter_esrf_mounting_points(bliss_raw_data_file)
+                bliss_raw_data_file = filter_esrf_mounting_points(
+                    str(pathlib.Path(bliss_raw_data_file))
+                )
                 strips = bliss_raw_data_file.lstrip("/").split("/")
                 if len(strips) > 2 and bliss_raw_data_file.startswith(
                     ("/data/visitor", "/data/visitor")
