@@ -6,17 +6,20 @@ import logging
 import os
 from glob import glob
 import functools
+import pathlib
 from typing import Iterable
 
 import numpy
 from silx.io.url import DataUrl
 from enum import Enum as _Enum
+from pathlib import Path
 
 from tomoscan.identifier import VolumeIdentifier
 from tomoscan.normalization import IntensityNormalization
 from tomoscan.volumebase import VolumeBase
 from tomoscan.identifier import BaseIdentifier
 from tomoscan.esrf.volume.utils import guess_volumes
+from tomoscan.utils.io import filter_esrf_mounting_points
 
 from tomwer.core.tomwer_object import TomwerObject
 from tomwer.core.utils.ftseriesutils import orderFileByLastLastModification
@@ -30,8 +33,8 @@ logger = logging.getLogger(__name__)
 
 class TomwerScanBase(TomwerObject):
     """
-    Simple interface to extend the tomoscan.TomwerScanBase with
-    specific functions
+    Interface to extend tomoscan.TomoScanBase with custom functionality.
+    ..warning:: All classes inheriting from this interface must also inherit from a child class of tomoscan.TomoScanBase
     """
 
     _DICT_DARK_REF_KEYS = "dark_ref_params"
@@ -86,11 +89,24 @@ class TomwerScanBase(TomwerObject):
         pass
 
     @property
-    def working_directory(self) -> str | None:
+    def resolved_path(self) -> str | None:
         """
-        working directory to use for this scan (for launching reconstruction for example)
+        return tomoscan 'path' with link resolved
         """
-        raise NotImplementedError("Base class")
+        if self.path is None:  # pylint: disable=E1101
+            return None
+        return filter_esrf_mounting_points(
+            str(Path(self.path).resolve())  # pylint: disable=E1101
+        )
+
+    @property
+    def working_directory(self) -> Path | None:
+        """
+        working directory once all links have been solved (required for submitting jobs to slurm)
+        """
+        if self.working_directory is None:
+            return None
+        return pathlib.Path(self.working_directory)
 
     def clear_cache(self):
         self._cache_proj_urls = None
@@ -246,13 +262,16 @@ class TomwerScanBase(TomwerObject):
         Return the two best opposite projections for the required mode.
         """
         radios_with_angle = self.projections_with_angle()
-        angles = numpy.array(
-            tuple(
-                filter(
-                    lambda a: numpy.issubdtype(type(a), numpy.number),
-                    radios_with_angle.keys(),
+        angles = (
+            numpy.array(
+                tuple(
+                    filter(
+                        lambda a: numpy.issubdtype(type(a), numpy.number),
+                        radios_with_angle.keys(),
+                    )
                 )
             )
+            % 360
         )
 
         from tomwer.core.process.reconstruction.axis.anglemode import CorAngleMode
@@ -266,18 +285,18 @@ class TomwerScanBase(TomwerObject):
             logger.warning("less than two angles found. Unable to get opposite angles")
             return None, None
 
-        initial_angle = angles[0]
+        initial_angle = angles[0] % 360
         if mode in (CorAngleMode.use_0_180, CorAngleMode.manual_selection):
-            couples = (initial_angle, initial_angle + 180.0)
+            couples = (initial_angle, (initial_angle + 180.0) % 360)
         elif mode is CorAngleMode.use_90_270:
-            couples = (initial_angle + 90.0, initial_angle + 270.0)
+            couples = ((initial_angle + 90.0) % 360, (initial_angle + 270.0) % 360)
         else:
             raise ValueError(f"{mode} is not handle")
 
         def find_nearest(angles: numpy.ndarray, angle: float):
             if len(angles) == 0:
                 return None
-            dist = numpy.abs(angles - angle)
+            dist = numpy.abs(angles % 360 - angle)
             idx = dist.argmin()
             if isinstance(idx, numpy.ndarray):
                 idx = idx[0]
@@ -496,10 +515,10 @@ class TomwerScanBase(TomwerObject):
         all_recons_ids = set()
         recons_paths = self.reconstruction_paths
         # extend set reconstruction paths to some 'default' paths.
-        if self.working_directory:
+        if self.working_directory is not None:
             # default output folder if using working directory
             working_dir_output_folder = os.path.join(
-                self.working_directory,
+                str(self.working_directory),
                 PROCESS_FOLDER_RECONSTRUCTED_SLICES,
             )
             # add possible output folder: in raw_data (deprecated)
