@@ -20,6 +20,6 @@ def test_working_directory():
     scan = EDFTomoScan(scan=None)
     assert scan.working_directory is None
     scan = EDFTomoScan(scan="my_folder")
-    assert scan.working_directory == os.path.abspath("my_folder")
+    assert str(scan.working_directory) == os.path.abspath("my_folder")
     scan = EDFTomoScan(scan="/full/path/to/my/folder")
-    assert scan.working_directory == os.path.abspath("/full/path/to/my/folder")
+    assert str(scan.working_directory) == os.path.abspath("/full/path/to/my/folder")
