@@ -11,12 +11,12 @@ def get_n_series(image_key_values: tuple | list, image_key_type: ImageKey) -> in
 
     :param image_key_values: list or tuple of image_keys to consider. Can be integers or tomoscan.esrf.scan.hdf5scan.ImageKey
     """
-    image_key_type = ImageKey.from_value(image_key_type)
+    image_key_type = ImageKey(image_key_type)
     if image_key_type is ImageKey.INVALID:
         raise ValueError(
             "we can't count Invalid image keys series because those are ignored from tomoscan"
         )
-    image_key_values = [ImageKey.from_value(img_key) for img_key in image_key_values]
+    image_key_values = [ImageKey(img_key) for img_key in image_key_values]
 
     # remove invalid frames
     image_key_values = numpy.array(
