@@ -39,8 +39,11 @@ def test_format_output_location(tmp_path):
         == "/test/my/output"
     )
 
-    hdf5_scan = NXtomoScan("/ddsad/my/file.hdf5", entry="entry0000")
+    hdf5_scan = NXtomoScan("/ddsad/my/file.hdf5", entry="nxtomos/entry0000")
     assert (
         format_output_location(location="{scan_basename}/output.nx", scan=hdf5_scan)
         == "/ddsad/my/output.nx"
     )
+    assert format_output_location(
+        location="{scan_file_name}/{scan_entry}.nx", scan=hdf5_scan
+    ) == os.path.abspath("file/nxtomos_entry0000.nx")
