@@ -17,7 +17,7 @@ from tomwer.gui.configuration.action import (
 )
 from tomwer.gui.configuration.level import ConfigurationLevel
 
-from nxtomomill.io.utils import convert_str_to_tuple
+from nxtomomill.models.utils import convert_str_to_tuple
 
 _logger = logging.getLogger(__name__)
 
