@@ -6,8 +6,9 @@ from collections import OrderedDict
 from typing import Any
 from nxtomomill import converter as nxtomomill_converter
 from nxtomomill.io import generate_default_edf_config, generate_default_h5_config
-from nxtomomill.io.config import TomoEDFConfig as EDFConfig
-from nxtomomill.io.config import TomoHDF5Config as HDF5Config
+from nxtomomill.models.h52nx import H52nxModel
+from nxtomomill.models.edf2nx import EDF2nxModel
+
 from silx.gui import qt
 
 from tomoscan.esrf.volume.utils import guess_volumes
@@ -32,6 +33,7 @@ from tomwer.gui.utils.inputwidget import (
 from tomwer.gui.utils.qt_utils import block_signals
 from tomwer.gui.control.tomoobjdisplaymode import DisplayMode
 from tomwer.gui.control.actions import TomoObjDisplayModeToolButton
+from tomwer.gui import icons
 
 logger = logging.getLogger(__name__)
 
@@ -114,6 +116,11 @@ class _DataListDialog(qt.QDialog):
 
 
 class _NXtomomillConfigFileDialog(qt.QDialog):
+
+    sigConfigFileChanged = qt.Signal(str)
+    sigOutputdirChanged = qt.Signal()
+    sigMechanicalFlipsChanged = qt.Signal()
+
     def __init__(
         self,
         parent,
@@ -131,7 +138,7 @@ class _NXtomomillConfigFileDialog(qt.QDialog):
         font.setPixelSize(12)
         self._warningLabel.setFont(font)
         self._warningLabel.setAlignment(qt.Qt.AlignLeft | qt.Qt.AlignVCenter)
-        #: add left intedation + lower size + italic
+        #: add left intendation + lower size + italic
         self.layout().addRow(self._warningLabel)
 
         # handle configuration file
@@ -150,6 +157,37 @@ class _NXtomomillConfigFileDialog(qt.QDialog):
         self._cdcfWidget.layout().addWidget(self._createDefaultConfigFileB)
         self.layout().addRow(self._cdcfWidget)
 
+        # vline 1
+        self._vLine1 = qt.QFrame()
+        self._vLine1.setFrameShape(qt.QFrame.Shape.HLine)
+        self._vLine1.setFrameShadow(qt.QFrame.Shadow.Sunken)
+        self.layout().addRow(self._vLine1)
+
+        # mechanical flips
+        self._lrMechanicalFlipLabel = qt.QLabel()
+        lr_icon = icons.getQIcon("lr_mirroring")
+        self._lrMechanicalFlip = qt.QCheckBox()
+        self._lrMechanicalFlip.setIcon(lr_icon)
+        self._lrMechanicalFlip.setToolTip(
+            "Detector image is flipped **left-right** for mechanical reasons that are not propagated with bliss-tomo hdf5 metadata (mirror,..)."
+        )
+        self.layout().addRow("left-right mechanical flip", self._lrMechanicalFlip)
+
+        self._udMechanicalFlipLabel = qt.QLabel("left-right mechanical flip")
+        ud_icon = icons.getQIcon("ud_mirroring")
+        self._udMechanicalFlip = qt.QCheckBox()
+        self._udMechanicalFlip.setIcon(ud_icon)
+        self._udMechanicalFlip.setToolTip(
+            "Detector image is flipped **up-down** for mechanical reasons that are not propagated with bliss-tomo hdf5 metadata (mirror,..)."
+        )
+        self.layout().addRow("up-down mechanical flip", self._udMechanicalFlip)
+
+        # vline 2
+        self._vLine2 = qt.QFrame()
+        self._vLine2.setFrameShape(qt.QFrame.Shape.HLine)
+        self._vLine2.setFrameShadow(qt.QFrame.Shadow.Sunken)
+        self.layout().addRow(self._vLine2)
+
         # handle configuration file
         self._nxTomomillOutputWidget = NXTomomillOutputDirSelector()
         self.layout().addRow("nexus file output dir", self._nxTomomillOutputWidget)
@@ -164,10 +202,12 @@ class _NXtomomillConfigFileDialog(qt.QDialog):
         self.__buttons.accepted.connect(self.accept)
         if callback_new_config_file is not None:
             self._createDefaultConfigFileB.released.connect(callback_new_config_file)
-
-        # expose API
-        self.sigConfigFileChanged = self._configurationWidget.sigConfigFileChanged
-        self.sigOutputdirChanged = self._nxTomomillOutputWidget.sigChanged
+        self._configurationWidget.sigConfigFileChanged.connect(
+            self.sigConfigFileChanged
+        )
+        self._nxTomomillOutputWidget.sigChanged.connect(self.sigOutputdirChanged)
+        self._lrMechanicalFlip.toggled.connect(self.sigMechanicalFlipsChanged)
+        self._udMechanicalFlip.toggled.connect(self.sigMechanicalFlipsChanged)
 
     def setNewconfigFileCreationCallback(self, callback):
         self._createDefaultConfigFile = callback
@@ -190,6 +230,16 @@ class _NXtomomillConfigFileDialog(qt.QDialog):
     def _createConfigFileSelector(self):
         raise NotImplementedError
 
+    def getMechanicalFlips(self) -> tuple[bool, bool]:
+        """
+        :return: mechanical flips as (left-right, up-down)
+        """
+        return self._lrMechanicalFlip.isChecked(), self._udMechanicalFlip.isChecked()
+
+    def setMechanicalFlips(self, lr_flip: bool, ud_flip: bool) -> None:
+        self._lrMechanicalFlip.setChecked(lr_flip)
+        self._udMechanicalFlip.setChecked(ud_flip)
+
 
 class BlissHDF5DataListDialog(_DataListDialog):
     """Dialog used to load .h5 files only (used for nxtomomillOW when we need to do a conversion from bliss.h5 to NXtomo)"""
@@ -227,7 +277,7 @@ class BlissHDF5DataListDialog(_DataListDialog):
         elif os.path.isdir("/data"):
             dialog.setDirectory("/data")
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
@@ -266,7 +316,7 @@ class EDFDataListDialog(_DataListDialog):
         elif os.path.isdir("/data"):
             dialog.setDirectory("/data")
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
@@ -343,6 +393,7 @@ class _RawDataListMainWindow(qt.QMainWindow):
         # connect signal / slot
         self._dialog.sigConfigFileChanged.connect(self._cfgFileChanged)
         self._dialog.sigOutputdirChanged.connect(self.sigUpdated)
+        self._dialog.sigMechanicalFlipsChanged.connect(self.sigUpdated)
         self._widget.sigUpdated.connect(self.sigUpdated)
         self._tomoObjdisplayAction.sigDisplayModeChanged.connect(self.setDisplayMode)
 
@@ -418,7 +469,7 @@ class BlissHDF5DataListMainWindow(_RawDataListMainWindow):
         super().__init__(
             parent,
             DataListConstructor=BlissHDF5DataListDialog,
-            ConfigClass=HDF5Config,
+            ConfigClass=H52nxModel,
             warning="""Note: some parameters of the configuration file will be ignored:\n
             - input_file will be replaced from the item of the data list treated
             - output_file will be deduce from the output folder you defined""",
@@ -429,7 +480,7 @@ class BlissHDF5DataListMainWindow(_RawDataListMainWindow):
 
     def _createNewConfigFile(self):  # pragma: no cover
         file_dialog = self.createNXtomomillConfigFileDialog()
-        if file_dialog.exec_():
+        if file_dialog.exec():
             files_selected = file_dialog.selectedFiles()
             if len(files_selected) > 0:
                 file_path = files_selected[0]
@@ -443,15 +494,15 @@ class BlissHDF5DataListMainWindow(_RawDataListMainWindow):
                     configuration = generate_default_h5_config(  # pylint: disable=E1123
                         config_3dxrd=False
                     )
-                HDF5Config.dict_to_cfg(file_path=file_path, dict_=configuration)
+                H52nxModel.dict_to_cfg(file_path=file_path, dict_=configuration)
                 # if we create a configuration file then let consider we want to use it
                 self.setCFGFilePath(file_path)
 
     def _load_cfg_file(self, cfg_file):
-        HDF5Config.from_cfg_file(cfg_file)
+        H52nxModel.from_cfg_file(cfg_file)
 
     def setConfiguration(self, config: dict):
-        if not isinstance(config, HDF5Config):
+        if not isinstance(config, H52nxModel):
             raise TypeError
         self.datalist.configuration = config
 
@@ -461,7 +512,7 @@ class EDFDataListMainWindow(_RawDataListMainWindow):
         super().__init__(
             parent,
             DataListConstructor=EDFDataListDialog,
-            ConfigClass=EDFConfig,
+            ConfigClass=EDF2nxModel,
             warning="""Note: some parameters of the configuration file will be ignored:\n
             - input_folder will be replaced from the item of the data list treated
             - dataset_basename (if will be deduce when the input folder is provided)
@@ -473,17 +524,17 @@ class EDFDataListMainWindow(_RawDataListMainWindow):
 
     def _createNewConfigFile(self):  # pragma: no cover
         file_dialog = self.createNXtomomillConfigFileDialog()
-        if file_dialog.exec_():
+        if file_dialog.exec():
             files_selected = file_dialog.selectedFiles()
             if len(files_selected) > 0:
                 file_path = files_selected[0]
                 configuration = generate_default_edf_config(level="advanced")
-                EDFConfig.dict_to_cfg(file_path=file_path, dict_=configuration)
+                EDF2nxModel.dict_to_cfg(file_path=file_path, dict_=configuration)
                 # if we create a configuration file then let consider we want to use it
                 self.setCFGFilePath(file_path)
 
     def _load_cfg_file(self, cfg_file):
-        EDFConfig.from_cfg_file(cfg_file)
+        EDF2nxModel.from_cfg_file(cfg_file)
 
 
 class GenericScanListDialog(_DataListDialog):
@@ -503,7 +554,7 @@ class GenericScanListDialog(_DataListDialog):
             ]
         )
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
@@ -565,7 +616,7 @@ class VolumeListDialog(_DataListDialog):
         """ """
         dialog = QVolumeDialog(self)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
         files_or_folders = dialog.files_selected()
@@ -828,7 +879,7 @@ class _TomwerObjectList(qt.QTableWidget):
     def contextMenuEvent(self, event):
         self._copy_target = self._datasetAt(event.pos())
         self._copyAction.setVisible(self._copy_target is not None)
-        self.menu.exec_(event.globalPos())
+        self.menu.exec(event.globalPos())
 
     def _copyRequested(self):
         clipboard = qt.QGuiApplication.clipboard()
@@ -897,7 +948,7 @@ class BlissScanList(_TomwerObjectList):
     HEADER_NAMES = ("bliss scan",)
 
     def __init__(self, parent):
-        self._configuration = HDF5Config()
+        self._configuration = H52nxModel()
         super().__init__(parent)
 
     @property
@@ -905,9 +956,9 @@ class BlissScanList(_TomwerObjectList):
         return self._configuration
 
     @configuration.setter
-    def configuration(self, config: HDF5Config):
+    def configuration(self, config: H52nxModel):
         assert isinstance(
-            config, HDF5Config
+            config, H52nxModel
         ), "config is expect to be an instance of dict"
         self._configuration = config
 
@@ -944,7 +995,7 @@ class BlissScanList(_TomwerObjectList):
                         "This is probably not a Bliss file. Do you still want to translate ?"
                     )
                 msg.setText(text)
-                if msg.exec_() != qt.QMessageBox.Ok:
+                if msg.exec() != qt.QMessageBox.Ok:
                     return
 
             try:
