@@ -205,7 +205,7 @@ class DataValidator(qt.QMainWindow, BaseDataValidator):
         """Callback when we want to add a new scan to the scan validator"""
         dialog = QDataDialog(self, multiSelection=True)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
