@@ -377,7 +377,7 @@ class DataWatcherWidget(_DataWatcher, qt.QMainWindow):
         dialog = qt.QFileDialog(self, directory=defaultDirectory)
         dialog.setFileMode(qt.QFileDialog.DirectoryOnly)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
