@@ -95,8 +95,8 @@ class ReduceDarkFlatSelectorTableWidget(qt.QWidget):
             # frame index
             indexItem = qt.QLineEdit(self._tree)
             # index can be provided as absolute indexes (integers)
-            validator = qt.QRegExpValidator(
-                qt.QRegExp(r"([+-]?([0-9]*[.])?[0-9]+)*[r]"), self
+            validator = qt.QRegularExpressionValidator(
+                qt.QRegularExpression(r"([+-]?([0-9]*[.])?[0-9]+)*[r]"), self
             )
             indexItem.setValidator(validator)
             indexItem.setText(str(frame_index))
@@ -287,11 +287,11 @@ class ReduceDarkFlatSelectorTableWidget(qt.QWidget):
                 h5file=url.file_path(),
                 path=url.data_path(),
             )
-            for target in REDUCER_TARGET.values():
-                if target in reduced_info_dict:
-                    reduced_frames = reduced_info_dict[target]
+            for target in REDUCER_TARGET:
+                if target.value in reduced_info_dict:
+                    reduced_frames = reduced_info_dict[target.value]
                     reduced_frames["reduce_frames_name"] = (
-                        f"{target} from {url.data_path()}@{os.path.basename(url.file_path())}"
+                        f"{target.value} from {url.data_path()}@{os.path.basename(url.file_path())}"
                     )
                     result.append(reduced_frames)
 
@@ -482,7 +482,7 @@ class ReduceDarkFlatSelectorDialog(qt.QDialog):
     def _addFromFileSelection(self):
         dialog = DataFileDialog()
         dialog.setDirectory(get_default_directory())
-        if dialog.exec_():
+        if dialog.exec():
             url = dialog.selectedUrl()
             reduced_frames_tuple = ReduceDarkFlatSelectorTableWidget.get_reduce_frames(
                 DataUrl(path=url)
