@@ -25,7 +25,7 @@ class ScanSelectorWidget(_SelectorWidget):
     def _callbackAddData(self):
         dialog = QDataDialog(self, multiSelection=True)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
