@@ -722,7 +722,7 @@ class SeriesManualDefinitionDialog(qt.QDialog):
     def addScanFromFileDialog(self) -> None:
         dialog = QDataDialog(self, multiSelection=True)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
