@@ -21,7 +21,7 @@ class VolumeSelectorWidget(_SelectorWidget):
     def _callbackAddData(self):
         dialog = QVolumeDialog(self)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
