@@ -195,7 +195,7 @@ class QVolumeDialog(qt.QDialog):
                 "raw files (*.vol *.raw)",
             ]
         )
-        if dialog.exec_() == qt.QDialog.Accepted:
+        if dialog.exec() == qt.QDialog.Accepted:
             selected_files = dialog.selectedFiles()
             if len(selected_files) > 0:
                 file_or_folder = selected_files[0]
@@ -223,7 +223,7 @@ class QVolumeDialog(qt.QDialog):
         dialog = DataFileDialog(self)
         dialog.selectFile(file_path)
 
-        if dialog.exec_():
+        if dialog.exec():
             try:
                 url = dialog.selectedUrl()
                 url = DataUrl(path=url)
