@@ -269,9 +269,9 @@ class _ListSelection(qt.QWidget):
         self._listQLE = qt.QLineEdit("", self)
         self._listQLE.setPlaceholderText("0, 8, -1, ...")
         self.layout().addWidget(self._listQLE)
-        reg_exp = qt.QRegExp(r"(\d+)(,[ ]?\s*\d+)*")
+        reg_exp = qt.QRegularExpression(r"(\d+)(,[ ]?\s*\d+)*")
         # list of int with optional space
-        validator = qt.QRegExpValidator(reg_exp)
+        validator = qt.QRegularExpressionValidator(reg_exp)
         self._listQLE.setValidator(validator)
 
         # select button
@@ -290,7 +290,7 @@ class _ListSelection(qt.QWidget):
         scan = self._scan()
         dialog = _FrameSelectionDialog(parent=self)
         dialog.setFrames(scan.frames)
-        if dialog.exec_():
+        if dialog.exec():
             frame_indexes = dialog.getSelectedFrameIndexes()
             return self.setList(frame_indexes)
 
