@@ -12,15 +12,20 @@ from nxtomo.application.nxtomo import NXtomo
 from nxtomo.nxobject.nxdetector import ImageKey, FOV
 from nxtomo.utils.transformation import (
     build_matrix,
+    DetXFlipTransformation,
     DetYFlipTransformation,
-    DetZFlipTransformation,
 )
-from nxtomo.nxobject.nxtransformations import NXtransformations
 
 from tomwer.core.process.edit.nxtomoeditor import NXtomoEditorTask
+from nxtomo.nxobject.nxtransformations import (
+    NXtransformations,
+    get_lr_flip,
+    get_ud_flip,
+)
 from tomwer.core.scan.nxtomoscan import NXtomoScan
 from tomwer.gui.edit.nxtomoeditor import NXtomoEditor, _TranslationMetricEntry
 from tomwer.tests.conftest import qtapp  # noqa F401
+from tomwer.tests.test_utils import is_lr_flip, is_ud_flip
 
 _ureg = pint.get_application_registry()
 
@@ -34,8 +39,8 @@ _ureg = pint.get_application_registry()
 @pytest.mark.parametrize("sample_source_distance", (-10.2 * _ureg.meter,))
 @pytest.mark.parametrize("propagation_distance", (1.01 * _ureg.meter,))
 @pytest.mark.parametrize("energy", (None, 23.5 * _ureg.keV))
-@pytest.mark.parametrize("x_flipped", (False,))
-@pytest.mark.parametrize("y_flipped", (True, False))
+@pytest.mark.parametrize("lr_flipped", (False,))
+@pytest.mark.parametrize("ud_flipped", (True, False))
 @pytest.mark.parametrize(
     "x_translation",
     (None, numpy.ones(12) * _ureg.meter, numpy.arange(12) * _ureg.meter),
@@ -56,11 +61,15 @@ def test_nx_editor(
     field_of_view,
     sample_detector_distance: pint.Quantity,
     energy: pint.Quantity,
-    x_flipped,
-    y_flipped,
+    lr_flipped,
+    ud_flipped,
     x_translation: pint.Quantity,
     z_translation: pint.Quantity,
 ):
+    """
+    :param x_translation: x translation on the ESRF coordinate system (will be converted to McStas coordinate when saved)
+    :param z_translation: z translation on the ESRF coordinate system (will be converted to McStas coordinate when saved)
+    """
     # 1.0 create nx tomo with raw data
     nx_tomo = NXtomo()
     nx_tomo.energy = energy
@@ -72,20 +81,17 @@ def test_nx_editor(
     nx_tomo.instrument.detector.data = numpy.empty(shape=(12, 10, 10))
 
     nx_tomo.sample.rotation_angle = numpy.linspace(0, 20, num=12) * _ureg.degree
-    nx_tomo.sample.x_translation = x_translation
-    nx_tomo.sample.z_translation = z_translation
+    # warning: mapping from ESRF coordinate to McStas
+    nx_tomo.sample.z_translation = x_translation
+    nx_tomo.sample.y_translation = z_translation
     nx_tomo.sample.x_pixel_size = sample_x_pixel_size
     nx_tomo.sample.y_pixel_size = sample_y_pixel_size
     nx_tomo.sample.propagation_distance = propagation_distance
 
     nx_tomo.instrument.source.distance = sample_source_distance
 
-    nx_tomo.instrument.detector.transformations.add_transformation(
-        DetZFlipTransformation(flip=x_flipped)
-    )
-    nx_tomo.instrument.detector.transformations.add_transformation(
-        DetYFlipTransformation(flip=y_flipped)
-    )
+    nx_tomo.instrument.detector.set_transformation_from_lr_flipped(flipped=lr_flipped)
+    nx_tomo.instrument.detector.set_transformation_from_ud_flipped(flipped=ud_flipped)
 
     file_path = os.path.join(tmp_path, "nxtomo.nx")
     entry = "entry0000"
@@ -131,8 +137,8 @@ def test_nx_editor(
         propagation_distance, widget._propagationDistanceMetricEntry.getValue()
     )
     assert field_of_view == widget._fieldOfViewCB.currentText()
-    assert x_flipped == widget._xFlippedCB.isChecked()
-    assert y_flipped == widget._yFlippedCB.isChecked()
+    assert lr_flipped == widget._lrFlippedCB.isChecked()
+    assert ud_flipped == widget._udFlippedCB.isChecked()
 
     if energy is None:
         assert widget._energyEntry.getValue() is None
@@ -169,7 +175,7 @@ def test_nx_editor(
     widget._sampleSourceDistanceMetricEntry.setValue(-99)
     widget._propagationDistanceMetricEntry.setValue(88)
     widget._fieldOfViewCB.setCurrentText(FOV.HALF.value)
-    widget._xFlippedCB.setChecked(not x_flipped)
+    widget._lrFlippedCB.setChecked(not lr_flipped)
     widget._xTranslationQLE.setValue(1.8)
     widget._xTranslationQLE.setUnit(_ureg.millimeter)
     widget._zTranslationQLE.setValue(2.8)
@@ -206,8 +212,8 @@ def test_nx_editor(
 
     final_transformation = NXtransformations()
 
-    final_transformation.add_transformation(DetYFlipTransformation(flip=y_flipped))
-    final_transformation.add_transformation(DetZFlipTransformation(flip=not x_flipped))
+    final_transformation.add_transformation(DetXFlipTransformation(flip=ud_flipped))
+    final_transformation.add_transformation(DetYFlipTransformation(flip=not lr_flipped))
     # note: the 'not' comes from inversion done with the _xFlippedCB combobox
 
     numpy.testing.assert_allclose(
@@ -243,8 +249,8 @@ def test_nx_editor_lock(
     nx_tomo_1.instrument.detector.y_pixel_size = 0.025 * _ureg.meter
     nx_tomo_1.instrument.detector.field_of_view = "full"
     nx_tomo_1.instrument.detector.distance = 2.4 * _ureg.meter
-    nx_tomo_1.instrument.detector.x_flipped = False
-    nx_tomo_1.instrument.detector.y_flipped = True
+    nx_tomo_1.instrument.detector.set_transformation_from_x_flipped(False)
+    nx_tomo_1.instrument.detector.set_transformation_from_y_flipped(True)
     nx_tomo_1.energy = 5.9 * _ureg.keV
     nx_tomo_1.instrument.detector.image_key_control = [ImageKey.PROJECTION.value] * 12
     nx_tomo_1.instrument.detector.data = numpy.empty(shape=(12, 10, 10))
@@ -268,12 +274,22 @@ def test_nx_editor_lock(
     nx_tomo_2.instrument.detector.y_pixel_size = 6.025 * _ureg.meter
     nx_tomo_2.instrument.detector.field_of_view = "full"
     nx_tomo_2.instrument.detector.distance = 2.89 * _ureg.meter
-    nx_tomo_2.instrument.detector.x_flipped = (
-        not nx_tomo_1.instrument.detector.x_flipped
-    )
-    nx_tomo_2.instrument.detector.y_flipped = (
-        not nx_tomo_1.instrument.detector.y_flipped
-    )
+    lr_flip_sum = [
+        trans.transformation_values
+        for trans in get_lr_flip(
+            nx_tomo_1.instrument.detector.transformations.transformations
+        )
+    ]
+    lr_flip = numpy.isclose(lr_flip_sum, 180.0)
+    nx_tomo_2.instrument.detector.set_transformation_from_x_flipped(not lr_flip)
+    ud_flip_sum = [
+        trans.transformation_values
+        for trans in get_ud_flip(
+            nx_tomo_1.instrument.detector.transformations.transformations
+        )
+    ]
+    ud_flip = numpy.isclose(ud_flip_sum, 180.0)
+    nx_tomo_2.instrument.detector.set_transformation_from_y_flipped(not ud_flip)
     nx_tomo_2.energy = 5.754 * _ureg.keV
     nx_tomo_2.instrument.detector.image_key_control = [ImageKey.PROJECTION.value] * 12
     nx_tomo_2.instrument.detector.data = numpy.empty(shape=(12, 10, 10))
@@ -303,8 +319,8 @@ def test_nx_editor_lock(
     assert widget._sampleDetectorDistanceMetricEntry.getValue() == 2.4 * _ureg.meter
     assert widget._propagationDistanceMetricEntry.getValue() == 22.0 * _ureg.meter
     assert widget._fieldOfViewCB.currentText() == "Full"
-    assert not widget._xFlippedCB.isChecked()
-    assert widget._yFlippedCB.isChecked()
+    assert not widget._lrFlippedCB.isChecked()
+    assert widget._udFlippedCB.isChecked()
     assert widget._xSamplePixelSizeMetricEntry.getValue() == 0.023 * _ureg.millimeter
     assert widget._ySamplePixelSizeMetricEntry.getValue() == 0.025 * _ureg.millimeter
     assert widget._sampleSourceDistanceMetricEntry.getValue() == 54.8 * _ureg.meter
@@ -339,14 +355,13 @@ def test_nx_editor_lock(
         overwrite_nx_tomo.instrument.detector.distance
         == nx_tomo_1.instrument.detector.distance
     )
-    assert (
-        overwrite_nx_tomo.instrument.detector.x_flipped
-        == nx_tomo_1.instrument.detector.x_flipped
-    )
-    assert (
-        overwrite_nx_tomo.instrument.detector.y_flipped
-        == nx_tomo_1.instrument.detector.y_flipped
-    )
+    assert is_lr_flip(
+        overwrite_nx_tomo.instrument.detector.transformations.transformations
+    ) == is_lr_flip(nx_tomo_1.instrument.detector.transformations.transformations)
+    assert is_ud_flip(
+        overwrite_nx_tomo.instrument.detector.transformations.transformations
+    ) == is_ud_flip(nx_tomo_1.instrument.detector.transformations.transformations)
+
     assert overwrite_nx_tomo.energy == nx_tomo_1.energy
     assert (
         overwrite_nx_tomo.sample.propagation_distance
@@ -364,8 +379,8 @@ def test_nx_editor_lock(
         "instrument.detector.field_of_view": ("Full", True),
         "instrument.detector.x_pixel_size": (0.023, True),
         "instrument.detector.y_pixel_size": (0.025, True),
-        "instrument.detector.x_flipped": (False, True),
-        "instrument.detector.y_flipped": (True, True),
+        "instrument.detector.lr_flipped": (False, True),
+        "instrument.detector.ud_flipped": (True, True),
         "instrument.source.distance": (54.8, True),
         "sample.propagation_distance": (22.0, True),
         "sample.x_pixel_size": (2.3e-5, True),
@@ -383,8 +398,8 @@ def test_nx_editor_lock(
         "instrument.detector.field_of_view": ("Full", False),
         "instrument.detector.x_pixel_size": (0.023, False),
         "instrument.detector.y_pixel_size": (0.025, False),
-        "instrument.detector.x_flipped": (False, False),
-        "instrument.detector.y_flipped": (True, False),
+        "instrument.detector.lr_flipped": (False, False),
+        "instrument.detector.ud_flipped": (True, False),
         "instrument.source.distance": (54.8, False),
         "sample.x_translation": (None,),
         "sample.z_translation": (None,),
