@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import pint
 from silx.gui import qt
 from processview.gui.DropDownWidget import DropDownWidget
 from tomwer.synctools.axis import QAxisRP
@@ -10,7 +11,8 @@ from tomwer.core.process.reconstruction.axis.side import Side
 from tomwer.core.process.reconstruction.axis import mode as axis_mode
 from tomwer.gui.fonts import FONT_SMALL
 from tomwer.gui.utils.scrollarea import QDoubleSpinBoxIgnoreWheel
-from pyunitsystem.metricsystem import MetricSystem
+
+_ureg = pint.get_application_registry()
 
 
 class EstimatedCORWidget(qt.QGroupBox):
@@ -345,19 +347,19 @@ class _OffsetCalibration(qt.QGroupBox):
     def _motorOffsetChanged(self):
         """Recalculate the offset when the motor offset changes."""
         if self._pixelSizeSB.value() and self._motorOffsetSB.value():
-            pixel_size_m = self._pixelSizeSB.value() * MetricSystem.MICROMETER.value
-            motor_offset_m = self._motorOffsetSB.value() * MetricSystem.MILLIMETER.value
+            pixel_size = self._pixelSizeSB.value() * _ureg.micrometer
+            motor_offset = self._motorOffsetSB.value() * _ureg.millimeter
             with block_signals(self):
-                self.setOffset(motor_offset_m / pixel_size_m)
+                self.setOffset((motor_offset / pixel_size).to_base_units().magnitude)
             self.sigOffsetChanged.emit()
 
     def _pixelSizeChanged(self):
         """Recalculate the offset when the pixel size changes."""
         if self._pixelSizeSB.value() and self._motorOffsetSB.value():
-            pixel_size_m = self._pixelSizeSB.value() * MetricSystem.MICROMETER.value
-            motor_offset_m = self._motorOffsetSB.value() * MetricSystem.MILLIMETER.value
+            pixel_size = self._pixelSizeSB.value() * _ureg.micrometer
+            motor_offset = self._motorOffsetSB.value() * _ureg.millimeter
             with block_signals(self):
-                self.setOffset(motor_offset_m / pixel_size_m)
+                self.setOffset((motor_offset / pixel_size).to_base_units().magnitude)
             self.sigOffsetChanged.emit()
 
     def _xRotationAxisPixelPositionEdited(self):
@@ -387,7 +389,9 @@ class _OffsetCalibration(qt.QGroupBox):
         if pixel_size_m is None:
             self._pixelSizeSB.clear()
         else:
-            self._pixelSizeSB.setValue(pixel_size_m / MetricSystem.MICROMETER.value)
+            self._pixelSizeSB.setValue(
+                (pixel_size_m * _ureg.meter).to(_ureg.micrometer).magnitude
+            )
 
     def _togglePixelSizeLock(self, locked: bool):
         """Lock or unlock the pixel size spin box."""
