@@ -13,7 +13,7 @@ from tomwer.core.process.reconstruction.nabu.castvolume import (
 from tomwer.core.process.reconstruction.output import NabuOutputFileFormat
 from tomwer.gui.qlefilesystem import QLFileSystem
 from tomwer.gui.reconstruction.nabu.nabuconfig.output import QNabuFileFormatComboBox
-from nxtomomill.io.utils import convert_str_to_tuple
+from nxtomomill.models.utils import convert_str_to_tuple
 
 _logger = logging.getLogger(__name__)
 
@@ -93,10 +93,10 @@ class CastVolumeWidget(qt.QWidget):
         self.layout().addWidget(self._cRatiosLabel, 5, 0, 1, 1)
         self._cRatiosQLE = qt.QLineEdit(self)
         fpm = "\\d*\\.?\\d+"  # float or int matching
-        qRegExp = qt.QRegExp(
+        qRegExp = qt.QRegularExpression(
             "(" + fpm + "[;]?[,]?[ ]?){1,}" + "|" + ":".join((fpm, fpm, fpm))
         )
-        self._cRatiosQLE.setValidator(qt.QRegExpValidator(qRegExp))
+        self._cRatiosQLE.setValidator(qt.QRegularExpressionValidator(qRegExp))
         self._cRatiosQLE.setPlaceholderText(
             "l1 compression rate, l2 compression rate..."
         )
