@@ -9,8 +9,6 @@ from tomwer.gui.reconstruction.nabu.nabuconfig import base
 from tomwer.gui.utils.illustrations import _IllustrationWidget
 from tomwer.gui.utils.scrollarea import QComboBoxIgnoreWheel
 
-from .reconstruction import AnglesFileWidget as Filewidget
-
 
 def nabu_param_ligne_to_dict(str_ligne: str) -> dict:
     ddict = {}
@@ -324,10 +322,6 @@ class CTFConfig(qt.QGroupBox, base._NabuStageConfigBase):
         self._geometryWidget = CTFGeometry(parent=self, title="geometry")
         self.layout().addRow(self._geometryWidget)
         self.registerWidget(self._geometryWidget, "optional")
-        # translation file
-        self._translationFile = Filewidget(self)
-        self.layout().addRow("translation file", self._translationFile)
-        self.registerWidget(self._translationFile, "optional")
         # advanced parameters
         self._advancedParamsWidget = CTFAdvancedParams(
             parent=self, title="advanced parameters"
@@ -338,7 +332,6 @@ class CTFConfig(qt.QGroupBox, base._NabuStageConfigBase):
         # connect signal / slot
         self._geometryWidget.sigConfChanged.connect(self._confChanged)
         self._advancedParamsWidget.sigConfChanged.connect(self._confChanged)
-        self._translationFile._qle.textEdited.connect(self._confChanged)
 
     def _confChanged(self, *args, **kwargs):
         self.sigConfChanged.emit("phase")
@@ -346,11 +339,8 @@ class CTFConfig(qt.QGroupBox, base._NabuStageConfigBase):
     def getConfiguration(self) -> dict:
         ddict = self._geometryWidget.getConfiguration()
         ddict.update(self._advancedParamsWidget.getConfiguration())
-        ddict["ctf_translations_file"] = self._translationFile.getFile()
         return ddict
 
     def setConfiguration(self, ddict):
         self._geometryWidget.setConfiguration(ddict=ddict)
         self._advancedParamsWidget.setConfiguration(ddict=ddict)
-        if "ctf_translations_file" in ddict:
-            self._translationFile.setFile(ddict["ctf_translations_file"])
