@@ -162,7 +162,7 @@ class NabuOutputLocationWidget(qt.QGroupBox):
         dialog = qt.QFileDialog(self, directory=defaultDirectory)
         dialog.setFileMode(qt.QFileDialog.DirectoryOnly)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
