@@ -5,7 +5,7 @@ from __future__ import annotations
 import logging
 
 from silx.gui import qt
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 from tomwer.core.process.reconstruction.nabu.utils import _NabuPhaseMethod, _NabuStages
 from tomwer.core.utils.char import BETA_CHAR, DELTA_CHAR
@@ -102,7 +102,7 @@ class _NabuPhaseConfig(qt.QWidget, base._NabuStageConfigBase):
         self.sigConfChanged.emit(param)
 
     def getMethod(self) -> _NabuPhaseMethod:
-        return _NabuPhaseMethod.from_value(self._methodCB.currentText())
+        return _NabuPhaseMethod(self._methodCB.currentText())
 
     @docstring(base._NabuStageConfigBase)
     def setConfiguration(self, config) -> None:
@@ -111,7 +111,7 @@ class _NabuPhaseConfig(qt.QWidget, base._NabuStageConfigBase):
             if method == "none":
                 method = _NabuPhaseMethod.NONE
             self._paganinOpts.setConfiguration(config)
-            method = _NabuPhaseMethod.from_value(method)
+            method = _NabuPhaseMethod(method)
             index_method = self._methodCB.findText(method.value)
             if index_method >= 0:
                 self._methodCB.setCurrentIndex(index_method)
@@ -212,10 +212,10 @@ class NabuPaganinConfig(qt.QWidget, base._NabuStageConfigBase):
 
     def getPaddingType(self) -> PaddingMode:
         current_text = self._paddingTypeCB.currentText()
-        return PaddingMode.from_value(current_text)
+        return PaddingMode(current_text)
 
     def setPaddingType(self, padding_type):
-        padding_type = PaddingMode.from_value(padding_type)
+        padding_type = PaddingMode(padding_type)
         item_index = self._paddingTypeCB.findText(padding_type.value)
         self._paddingTypeCB.setCurrentIndex(item_index)
 
