@@ -643,13 +643,13 @@ class TiltCorrection(qt.QGroupBox):
         self.setCheckable(True)
         self.setLayout(qt.QFormLayout())
         self._tiltManualRB = qt.QRadioButton("angle", self)
-        self._angleValueSB = qt.QDoubleSpinBox(self)
+        self._angleValueSB = QDoubleSpinBox(self)
         self._angleValueSB.setRange(-360, 360)
         self._angleValueSB.setSuffix("°")
         self.layout().addRow(self._tiltManualRB, self._angleValueSB)
 
         self._autoManualRB = qt.QRadioButton("auto", self)
-        self._autoModeCB = qt.QComboBox(self)
+        self._autoModeCB = QComboBox(self)
         self._modes = {
             "1d-correlation": "auto-detect tilt with the 1D correlation method (fastest, but works best for small tilts)",
             "fft-polar": "auto-detect tilt with polar FFT method (slower, but works well on all ranges of tilts)",
@@ -753,7 +753,7 @@ class RotateProjectionCenterWidget(qt.QWidget):
         self._label = qt.QLabel("rotate projections center")
         self.layout().addWidget(self._label)
 
-        self._xQLE = qt.QDoubleSpinBox(self)
+        self._xQLE = QDoubleSpinBox(self)
         self._xQLE.setRange(
             RotateProjectionCenterWidget.RANGE_MIN_VALUE,
             RotateProjectionCenterWidget.RANGE_MAX_VALUE,
@@ -763,7 +763,7 @@ class RotateProjectionCenterWidget(qt.QWidget):
         self._xQLE.setSuffix("px")
         self.layout().addWidget(self._xQLE)
 
-        self._yQLE = qt.QDoubleSpinBox(self)
+        self._yQLE = QDoubleSpinBox(self)
         self._yQLE.setRange(
             RotateProjectionCenterWidget.RANGE_MIN_VALUE,
             RotateProjectionCenterWidget.RANGE_MAX_VALUE,
