@@ -9,7 +9,7 @@ from silx.gui import qt
 from silx.gui.dialog.DataFileDialog import DataFileDialog
 from enum import Enum as _Enum
 
-from nxtomomill.io.utils import convert_str_to_tuple
+from nxtomomill.models.utils import convert_str_to_tuple
 from tomwer.core.utils.char import DEGREE_CHAR
 from tomwer.core.process.reconstruction.nabu.plane import NabuPlane
 from tomwer.core.process.reconstruction.nabu.nabuslices import NabuSliceMode
@@ -196,7 +196,7 @@ class TranslationMvtFileWidget(qt.QWidget):
         dialog = DataFileDialog()
         dialog.setFilterMode(DataFileDialog.FilterMode.ExistingDataset)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
         else:
@@ -206,7 +206,7 @@ class TranslationMvtFileWidget(qt.QWidget):
         dialog = qt.QFileDialog(self)
         dialog.setFileMode(qt.QFileDialog.ExistingFile)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
         if len(dialog.selectedFiles()) > 0:
@@ -274,7 +274,7 @@ class AnglesFileWidget(qt.QWidget):
             ]
         )
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
         elif len(dialog.selectedFiles()) == 0:
