@@ -352,7 +352,7 @@ class NabuWindow(qt.QMainWindow):
         dialog.setAcceptMode(acceptMode)
         dialog.setFileMode(qt.QFileDialog.AnyFile)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
