@@ -29,12 +29,10 @@ class TestFutureSupervisorOW(TestCaseQt):
         assert config == {
             "ctf_geometry": " z1_v=None; z1_h=None; detec_pixel_size=None; magnification=True",
             "ctf_advanced_params": " length_scale=1e-05; lim1=1e-05; lim2=0.2; normalize_by_mean=True",
-            "ctf_translations_file": "",
             "beam_shape": "parallel",
         }
 
         config["beam_shape"] = "cone"
-        config["ctf_translations_file"] = "my_file.txt"
         config["ctf_geometry"] = (
             " z1_v=10.2; z1_h=3.6; detec_pixel_size=1e-05; magnification=False"
         )
