@@ -330,7 +330,7 @@ class NabuVolumeWidget(_NabuStageConfigBase, qt.QWidget):
             self.setHistogramRequested(requested=bool(config["output_histogram"]))
 
     def setConfigurationLevel(self, level):
-        level = ConfigurationLevel.from_value(level)
+        level = ConfigurationLevel(level)
         _NabuStageConfigBase.setConfigurationLevel(self, level)
 
     def getConfigurationLevel(self):
