@@ -810,7 +810,7 @@ class _NormIntensityDatasetWidget(qt.QWidget):
         dialog = qt.QFileDialog(self)
         dialog.setNameFilters(["HDF5 file *.h5 *.hdf5 *.nx *.nxs *.nexus"])
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
@@ -853,7 +853,7 @@ class _NormIntensityDatasetWidget(qt.QWidget):
         dialog.selectFile(file_)
         dialog.setFilterMode(DataFileDialog.FilterMode.ExistingDataset)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
         else:
