@@ -275,7 +275,7 @@ class _ReconstructionModeGB(qt.QGroupBox):
         if scan is None:
             _logger.info("No scan defined, request user for defining the image" "url")
             dialog = ImageFileDialog()
-            if dialog.exec_():
+            if dialog.exec():
                 data = dialog.selectedImage()
             else:
                 return
@@ -291,7 +291,7 @@ class _ReconstructionModeGB(qt.QGroupBox):
 
         lineSelection.setData(data)
         lineSelection.setSelection(list(self.getReconstructionSlices().values()))
-        if lineSelection.exec_() == qt.QDialog.Accepted:
+        if lineSelection.exec() == qt.QDialog.Accepted:
             selection = lineSelection.getSelection()
             if selection is not None and len(selection) > 0:
                 self.setReconstructionSlices({"Slice": selection[0]})
