@@ -103,7 +103,7 @@ class DimensionWidget(qt.QGroupBox):
                 f"unit is expected be an instance of {pint.Unit}. Got {type(unit)}"
             )
         for widget in (self._dim0ValueQLE, self._dim1ValueQLE, self._dim2ValueQLE):
-            widget.setSuffix(f"{self._displayUnit:~}")
+            widget.setSuffix(f"{self._displayUnit:.4f~P}")
         # convert current values
         self._dim0Value = self._dim0Value.magnitude * self._displayUnit
         self._dim1Value = self._dim1Value.magnitude * self._displayUnit
