@@ -16,7 +16,6 @@ from tomwer.core.process.reconstruction.saaxis.params import SAAxisParams
 from tomwer.core.process.reconstruction.saaxis.saaxis import SAAxisTask
 from tomwer.gui import icons
 from tomwer.gui.reconstruction.axis.CalculationWidget import CalculationWidget
-from tomwer.gui.reconstruction.nabu.slices import NabuWidget
 from tomwer.gui.reconstruction.nabu.platform import NabuPlatformSettings
 from tomwer.gui.reconstruction.saaxis.corrangeselector import SliceAndCorWidget
 from tomwer.gui.reconstruction.scores.control import ControlWidget
@@ -25,6 +24,8 @@ from tomwer.gui.reconstruction.scores.scoreplot import ScorePlot as _ScorePlot
 from tomwer.gui.utils.buttons import TabBrowsersButtons
 from tomwer.gui.utils.scandescription import ScanNameLabelAndShape
 from tomwer.gui.settings import TAB_LABEL_PLATFORM_SETTINGS
+from tomwer.gui.reconstruction.sacommon import NabuWidgetWithToolbar as NabuWidget
+
 from tomwer.synctools.axis import QAxisRP
 
 _logger = logging.getLogger(__file__)
@@ -128,6 +129,7 @@ class _SAAxisTabWidget(qt.QTabWidget):
         self._nabuSettings.hideSlicesInterface()
         nabu_icon = icons.getQIcon("nabu")
         self.addTab(self._nabuSettings, nabu_icon, "reconstruction settings")
+
         # platform settings
         self._localPlatformSettings = NabuPlatformSettings(self)
         settings_icons = icons.getQIcon("parameters")
