@@ -25,7 +25,6 @@ from tomwer.core.process.reconstruction.scores.params import ScoreMethod
 from tomwer.core.scan.scanbase import TomwerScanBase
 from tomwer.gui import icons
 from tomwer.gui.reconstruction.nabu.nabuconfig.phase import _NabuPhaseConfig
-from tomwer.gui.reconstruction.nabu.slices import NabuWidget
 from tomwer.gui.reconstruction.nabu.platform import NabuPlatformSettings
 from tomwer.gui.reconstruction.saaxis.sliceselector import SliceSelector
 from tomwer.gui.reconstruction.scores.control import ControlWidget
@@ -35,6 +34,7 @@ from tomwer.gui.utils.buttons import TabBrowsersButtons
 from tomwer.gui.utils.scandescription import ScanNameLabelAndShape
 from tomwer.gui.settings import TAB_LABEL_PLATFORM_SETTINGS
 from tomwer.synctools.sadeltabeta import QSADeltaBetaParams
+from tomwer.gui.reconstruction.sacommon import NabuWidgetWithToolbar as NabuWidget
 
 _logger = logging.getLogger(__name__)
 
