@@ -201,7 +201,7 @@ class VariableSelection(qt.QWidget):
         # set scores
         dialog.setScores(self._scores, score_method=self.getScoreMethod())
 
-        if dialog.exec_() == qt.QDialog.Accepted:
+        if dialog.exec() == qt.QDialog.Accepted:
             cor_selected = dialog.selectedValue()
             if cor_selected is not None:
                 self.sigVariableValueSelected.emit(cor_selected)
@@ -800,7 +800,7 @@ class ScorePlot(qt.QWidget):
         """
         dialog = qt.QFileDialog(self, directory=get_default_directory())
         dialog.setFileMode(qt.QFileDialog.DirectoryOnly)
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
