@@ -3,6 +3,7 @@ from __future__ import annotations
 
 
 import os
+import pint
 import shutil
 import tempfile
 
@@ -12,7 +13,6 @@ import pytest
 from silx.gui import qt
 from silx.gui.utils.testutils import TestCaseQt
 from silx.io.url import DataUrl
-from pyunitsystem.metricsystem import MetricSystem
 
 from tomwer.core.process.reconstruction.saaxis.params import (
     ReconstructionMode,
@@ -26,6 +26,9 @@ from tomwer.gui.reconstruction.saaxis.saaxis import SAAxisWindow
 from tomwer.tests.utils import skip_gui_test
 
 
+_ureg = pint.get_application_registry()
+
+
 @pytest.mark.skipif(skip_gui_test(), reason="skip gui test")
 class TestDimensionWidget(TestCaseQt):
     """Test that the axis widget work correctly"""
@@ -39,51 +42,50 @@ class TestDimensionWidget(TestCaseQt):
 
     def testDimension(self):
         """Insure setting dimensions values and unit are correct"""
-        self.assertTrue(self._window.unit() is MetricSystem.MILLIMETER)
         # check initial values
         self.assertEqual(
-            self._window.getValues(),
-            (0.001, 0.001, 0.001, MetricSystem.METER),
+            self._window.getQuantities(),
+            (1.0 * _ureg.millimeter, 1.0 * _ureg.millimeter, 1.0 * _ureg.millimeter),
         )
         # set dim 0 to 20 mm
         self._window._dim0ValueQLE.setValue(20)
         self._window._dim0ValueQLE.editingFinished.emit()
         self.qapp.processEvents()
         self.assertEqual(
-            self._window.getValues(),
-            (0.02, 0.001, 0.001, MetricSystem.METER),
+            self._window.getQuantities(cast_unit_to=_ureg.meter),
+            (0.02 * _ureg.meter, 0.001 * _ureg.meter, 0.001 * _ureg.meter),
         )
         # set dim 1 to 0.6 millimeter
         self._window._dim1ValueQLE.setValue(0.6)
         self._window._dim1ValueQLE.editingFinished.emit()
         self.qapp.processEvents()
         self.assertEqual(
-            self._window.getValues(),
-            (0.02, 0.0006, 0.001, MetricSystem.METER),
+            self._window.getQuantities(cast_unit_to=_ureg.meter),
+            (0.02 * _ureg.meter, 0.0006 * _ureg.meter, 0.001 * _ureg.meter),
         )
         # change display to micrometer
-        self._window.setUnit(MetricSystem.MICROMETER)
+        self._window.setUnit(_ureg.millimeter)
         self.assertEqual(
-            self._window.getValues(),
-            (0.02, 0.0006, 0.001, MetricSystem.METER),
+            self._window.getQuantities(cast_unit_to=_ureg.meter),
+            (0.02 * _ureg.meter, 0.0006 * _ureg.meter, 0.001 * _ureg.meter),
         )
         self.assertEqual(
-            self._window._dim0ValueQLE.value(),
-            20 * MetricSystem.MILLIMETER.value / MetricSystem.MICROMETER.value,
+            self._window._dim0Value,
+            20 * _ureg.millimeter,
         )
         self._window._dim2ValueQLE.setValue(500)
         self._window._dim2ValueQLE.editingFinished.emit()
         self.qapp.processEvents()
         self.assertEqual(
-            self._window.getValues(),
-            (0.02, 0.0006, 0.0005, MetricSystem.METER),
+            self._window.getQuantities(cast_unit_to=_ureg.meter),
+            (0.02 * _ureg.meter, 0.0006 * _ureg.meter, 0.5 * _ureg.meter),
         )
 
     def testConstructorWithColors(self):
         """Insure passing colors works"""
         DimensionWidget(title="title", dims_colors=("#ffff5a", "#62efff", "#ff5bff"))
 
-    def testConstructorWithdimNames(self):
+    def testConstructorWithDimNames(self):
         """Insure passing colors works"""
         DimensionWidget(title="title", dims_name=("x", "y", "z"))
 
