@@ -88,7 +88,7 @@ class QImageFileStackPlot(ImageStack):
                 msg.setIcon(qt.QMessageBox.Warning)
                 msg.setWindowTitle("Unable to open image in imagej")
                 msg.setText(str(e))
-                msg.exec_()
+                msg.exec()
 
     def _updateUrlInfos(self):
         url = self.getCurrentUrl()
