@@ -81,7 +81,7 @@ class _ImageStack(qt.QMainWindow):
             ]
         )
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
