@@ -13,7 +13,7 @@ from nabu.stitching.config import (
 )
 from nabu.stitching.utils import ShiftAlgorithm as StitchShiftAlgorithm
 
-from nxtomomill.io.utils import convert_str_to_bool as _convert_str_to_bool
+from nxtomomill.models.utils import convert_str_to_bool as _convert_str_to_bool
 
 from tomwer.gui.configuration.level import ConfigurationLevel
 from tomwer.gui.stitching.config.stitchingstrategies import StitchingStrategies
