@@ -360,7 +360,7 @@ class _SingleAxisStitchingWindow(
         if file_path is None:
             dialog = QConfigFileDialog(self)
             dialog.setAcceptMode(qt.QFileDialog.AcceptSave)
-            if not dialog.exec_():
+            if not dialog.exec():
                 return
 
             selected_file = dialog.selectedFiles()
@@ -396,7 +396,7 @@ class _SingleAxisStitchingWindow(
             dialog.setAcceptMode(qt.QFileDialog.AcceptOpen)
             dialog.setFileMode(qt.QFileDialog.ExistingFiles)
 
-            if not dialog.exec_():
+            if not dialog.exec():
                 return
 
             selected_file = dialog.selectedFiles()
