@@ -370,7 +370,7 @@ class EditableOrderedTomoObjWidget(AxisOrderedTomoObjWidget):
             ]
         )
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return ()
         elif len(dialog.selectedFiles()) == 0:
