@@ -80,10 +80,10 @@ class StitcherAxisParams(qt.QWidget):
         return self._axis
 
     def getShiftSearchMethod(self) -> StitchShiftAlgorithm:
-        return StitchShiftAlgorithm.from_value(self._shiftSearchMethodCB.currentText())
+        return StitchShiftAlgorithm(self._shiftSearchMethodCB.currentText())
 
     def setShiftSearchMethod(self, method: StitchShiftAlgorithm | str) -> None:
-        method = StitchShiftAlgorithm.from_value(method)
+        method = StitchShiftAlgorithm(method)
         idx = self._shiftSearchMethodCB.findText(method.value)
         self._shiftSearchMethodCB.setCurrentIndex(idx)
 
