@@ -2,13 +2,14 @@ import logging
 
 from nabu.stitching import config as stitching_config
 from nabu.stitching.config import StitchingType
-from nxtomomill.io.utils import convert_str_to_bool
+from nxtomomill.models.utils import convert_str_to_bool
 from silx.gui import qt
 
 from tomwer.core.scan.nxtomoscan import NXtomoScan, NXtomoScanIdentifier
 from tomwer.core.scan.scanfactory import ScanFactory
 from tomwer.gui.utils.inputwidget import OutputVolumeDefinition
 from tomwer.gui.qlefilesystem import QLFileSystem
+from silx.io.url import DataUrl
 
 _logger = logging.getLogger(__name__)
 
@@ -20,12 +21,24 @@ class _PreProcessingOutput(qt.QWidget):
 
     def __init__(self, parent=None) -> None:
         super().__init__(parent)
-        self.setLayout(qt.QFormLayout())
+        self.setLayout(qt.QGridLayout())
         # TODO: check if the widget with output .nx file exists somewhere
-        self._outputFile = QLFileSystem("stitching/stitched.nx", self)
-        self.layout().addRow("output nexus file", self._outputFile)
-        self._outputDataPath = qt.QLineEdit("entry0000", self)
-        self.layout().addRow("output data path", self._outputDataPath)
+        # output file
+        self._outputFile = QLFileSystem("", self)
+        self._outputFileLabel = qt.QLabel("output nexus file")
+        self.layout().addWidget(self._outputFileLabel, 0, 0, 1, 1)
+        self.layout().addWidget(self._outputFile, 0, 1, 1, 1)
+        self._selectPB = qt.QPushButton("select", self)
+        self.layout().addWidget(self._selectPB, 0, 2, 1, 1)
+
+        self._outputDataPathLabel = qt.QLabel("output data path")
+        self.layout().addWidget(self._outputDataPathLabel, 1, 0, 2, 1)
+        self._outputDataPath = qt.QLineEdit("", self)
+        self._outputDataPath.setToolTip("Location of the dataset **inside** the file.")
+        self.layout().addWidget(self._outputDataPath, 1, 1, 1, 2)
+
+        # connect signal / slot
+        self._selectPB.released.connect(self._selectNxTomoFile)
 
     def getUrl(self) -> str:
         return NXtomoScanIdentifier(
@@ -43,6 +56,22 @@ class _PreProcessingOutput(qt.QWidget):
             self._outputFile.setText(identifier.file_path)
             self._outputDataPath.setText(identifier.data_path)
 
+    def _selectNxTomoFile(self):
+        dialog = qt.QFileDialog(self)
+        dialog.setNameFilters(
+            [
+                "Any files (*)",
+                "HDF5 files (*.h5 *.hdf5 *.nx *.nxs *.nexus)",
+                "Nexus files (*.nx *.nxs *.nexus)",
+            ]
+        )
+        if not dialog.exec():
+            dialog.close()
+        elif len(dialog.selectedFiles()) == 0:
+            return
+        else:
+            self._outputFile.setText(dialog.selectedFiles()[0])
+
 
 class _PostProcessingOutput(OutputVolumeDefinition):
     """
@@ -72,7 +101,7 @@ class StitchingOutput(qt.QWidget):
         self.layout().addWidget(self._preProcOutput)
         self._postProcOutput = _PostProcessingOutput(parent=self)
         self.layout().addWidget(self._postProcOutput)
-        self._overwritePB = qt.QCheckBox("overwrite", self)
+        self._overwritePB = qt.QCheckBox("Overwrite", self)
         self._overwritePB.setChecked(True)
         self.layout().addWidget(self._overwritePB)
 
@@ -84,7 +113,7 @@ class StitchingOutput(qt.QWidget):
         self._updateOutputForStitchingType(StitchingType.Z_PREPROC)
 
     def _updateOutputForStitchingType(self, stitching_type):
-        self.__stitching_type = StitchingType.from_value(stitching_type)
+        self.__stitching_type = StitchingType(stitching_type)
         self._preProcOutput.setVisible(self.__stitching_type is StitchingType.Z_PREPROC)
         self._postProcOutput.setVisible(
             self.__stitching_type is StitchingType.Z_POSTPROC
@@ -114,8 +143,8 @@ class StitchingOutput(qt.QWidget):
                 scan = None
 
             if not isinstance(scan, NXtomoScan):
-                _logger.info("Failed to create an HDFTomoscan from url")
-                return None
+                _logger.warning("Failed to create an HDF5Tomoscan from url")
+                pass
             else:
                 config.update(
                     {
@@ -125,7 +154,7 @@ class StitchingOutput(qt.QWidget):
                         },
                     }
                 )
-                return config
+            return config
         else:
             raise NotImplementedError
 
@@ -160,3 +189,10 @@ class StitchingOutput(qt.QWidget):
         if overwrite is not None:
             overwrite = convert_str_to_bool(overwrite)
             self._overwritePB.setChecked(overwrite)
+
+    # expose API
+    def setPreProcessingOutput(self, identifier: str) -> None:
+        self._preProcOutput.setUrl(identifier)
+
+    def setPostProcessingOutput(self, identifier: DataUrl) -> None:
+        self._postProcOutput.setUrl(identifier)
