@@ -368,9 +368,9 @@ class RawStitchingPlot(PlotWindow):
                 (slice_to_use,),
             )[0]
 
-            if scan.get_x_flipped(default=False) ^ self._fliplrFrames:
+            if (scan.detector_is_lr_flip or False) ^ self._fliplrFrames:
                 ff = numpy.fliplr(ff)
-            if scan.get_y_flipped(default=False) ^ self._flipudFrames:
+            if (scan.detector_is_ud_flip or False) ^ self._flipudFrames:
                 ff = numpy.flipud(ff)
 
             return ff
