@@ -29,7 +29,11 @@ def create_scans_z_series(
     flip_ud: bool = False,
 ):
     """
-    :param Optional tuple: shift to be applied on the 2D frame
+    :param z_positions_m: positions along the Z axis in meter (in the ESRF coordinate system). Warning: those position will be saved under the McStas coordinate system (y axis)
+    :param x_positions_m: positions along the x axis in meter (in the ESRF coordinate system). Warning: those position will be saved under the McStas coordinate system (z axis)
+    :param shifts: shift to be applied on the 2D frame
+
+
     """
     if not os.path.exists(output_dir):
         os.makedirs(output_dir)
@@ -49,9 +53,11 @@ def create_scans_z_series(
     ):
         nx_tomo = NXtomo()
         if z_pos is not None:
-            nx_tomo.sample.z_translation = ([z_pos] * n_proj) * _ureg.meter
+            # warning: doing mapping from esrf coordinate system to McStas (used by NXtomo)
+            nx_tomo.sample.y_translation = ([z_pos] * n_proj) * _ureg.meter
         if x_pos is not None:
-            nx_tomo.sample.x_translation = ([x_pos] * n_proj) * _ureg.meter
+            # warning: doing mapping from esrf coordinate system to McStas (used by NXtomo)
+            nx_tomo.sample.z_translation = ([x_pos] * n_proj) * _ureg.meter
         nx_tomo.sample.rotation_angle = (
             numpy.linspace(0, 180, num=n_proj, endpoint=False) * _ureg.degree
         )
