@@ -1,6 +1,9 @@
+from __future__ import annotations
+
 import os
 import shutil
 import tempfile
+import pint
 
 from silx.gui import qt
 from silx.gui.utils.testutils import TestCaseQt
@@ -9,6 +12,9 @@ from tomwer.gui.stitching.tests.utils import create_scans_z_series
 from tomwer.gui.stitching.StitchingWindow import ZStitchingWindow
 
 
+_ureg = pint.get_application_registry()
+
+
 class TestZStichingWindow(TestCaseQt):
     """
     Test high level z stitching definition
@@ -20,7 +26,7 @@ class TestZStichingWindow(TestCaseQt):
         self.scans = create_scans_z_series(
             os.path.join(self._tmp_path, "case1"),
             z_positions_m=(0.200, 0.205, 0.210),
-            pixel_size=0.001,
+            sample_pixel_size=0.001,
             raw_frame_width=100,
         )
 
@@ -45,7 +51,6 @@ class TestZStichingWindow(TestCaseQt):
         self._widget.show()
         # fill the widget with scans
 
-        scan_0, scan_1, scan_2 = self.scans
         for scan in self.scans:
             self._widget.addTomoObj(scan)
             # note: add the sigChanged to the z ordered list 'update z' slot
