@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import sys
 from silx.gui import qt
+from tomwer.gui.utils.scrollarea import QDoubleSpinBoxIgnoreWheel as QDoubleSpinBox
 
 
 class RangeWidget(qt.QWidget):
@@ -15,13 +16,13 @@ class RangeWidget(qt.QWidget):
 
         # start
         self.layout().addWidget(qt.QLabel("from"))
-        self._startQLE = qt.QDoubleSpinBox(self)
+        self._startQLE = QDoubleSpinBox(self)
         self.layout().addWidget(self._startQLE)
         self._startQLE.setRange(sys.float_info.min, sys.float_info.max)
 
         # stop
         self.layout().addWidget(qt.QLabel("to"))
-        self._stopQLE = qt.QDoubleSpinBox(self)
+        self._stopQLE = QDoubleSpinBox(self)
         self.layout().addWidget(self._stopQLE)
         self._stopQLE.setRange(sys.float_info.min, sys.float_info.max)
 
