@@ -88,11 +88,11 @@ class TabBrowsersButtons(qt.QWidget):
 class TapeMeasureToolButton(PlotToolButton):
     """Button to active measurement between two point of the plot"""
 
-    def __init__(self, parent=None, plot=None, pixel_size_mm=None):
+    def __init__(self, parent=None, plot=None, pixel_size: pint.Quantity | None = None):
         super().__init__(parent=parent, plot=plot)
         self._roiManager = None
         self._lastRoiCreated = None
-        self._pixel_size_m = pixel_size_mm
+        self._pixel_size: pint.Quantity | None = pixel_size
         self.setIcon(icons.getQIcon("ruler"))
         self.setToolTip("measure distance between two pixels")
         self.toggled.connect(self._callback)
@@ -101,8 +101,8 @@ class TapeMeasureToolButton(PlotToolButton):
     def setPlot(self, plot):
         return super().setPlot(plot)
 
-    def setPixelSize(self, pixel_size_m: tuple | float | None):
-        self._pixel_size_m = pixel_size_m
+    def setPixelSize(self, pixel_size: tuple[pint.Quantity, pint.Quantity] | None):
+        self._pixel_size = pixel_size
 
     def _callback(self, toggled):
         if not self._roiManager:
@@ -151,43 +151,45 @@ class TapeMeasureToolButton(PlotToolButton):
     def _registerCurrentROI(self, currentRoi):
         if self._lastRoiCreated is None:
             self._lastRoiCreated = currentRoi
-            self._lastRoiCreated.setPixelSize(self._pixel_size_m)
+            self._lastRoiCreated.setPixelSize(self._pixel_size)
         elif currentRoi != self._lastRoiCreated and self._roiManager is not None:
             self._roiManager.removeRoi(self._lastRoiCreated)
             self._lastRoiCreated = currentRoi
-            self._lastRoiCreated.setPixelSize(self._pixel_size_m)
+            self._lastRoiCreated.setPixelSize(self._pixel_size)
 
 
 class TapeMeasureROI(LineROI):
     """ROI dedicated to tape measure"""
 
-    def __init__(self, parent=None, pixel_size_m=None):
+    def __init__(self, parent=None, pixel_size: pint.Quantity | None = None):
         super().__init__(parent)
-        self._pixel_size_m = None
-        self.setPixelSize(pixel_size_m)
+        self._pixel_size: pint.Quantity | None = None
+        self.setPixelSize(pixel_size)
 
     def setEndPoints(self, startPoint, endPoint):
         distance_px = numpy.linalg.norm(endPoint - startPoint)
         super().setEndPoints(startPoint=startPoint, endPoint=endPoint)
-        if self._pixel_size_m is None:
+        if self._pixel_size is None:
             self._updateText(f"{distance_px :.1f}px")
         else:
-            distance_m = distance_px * self._pixel_size_m
+            distance_m = distance_px * self._pixel_size
             value = self.cast_metric_to_best_unit(distance_m)
-            self._updateText(f"{distance_px :.1f}px ({value:~})")
+            self._updateText(f"{value:.4f~P}")
 
-    def setPixelSize(self, pixel_size_m: tuple | float | None):
-        if isinstance(pixel_size_m, (tuple, list)):
+    def setPixelSize(self, pixel_size: tuple[pint.Quantity]):
+        if isinstance(pixel_size, (tuple, list)):
             assert (
-                len(pixel_size_m) == 2
+                len(pixel_size) == 2
             ), "expects at most two pixel size values (x and y values)"
-            if not numpy.isclose(pixel_size_m[0], pixel_size_m[1]):
-                value = self.cast_metric_to_best_unit(pixel_size_m[0] * _ureg.meter)
+            if not numpy.isclose(
+                pixel_size[0].to_base_units(), pixel_size[1].to_base_units()
+            ):
+                value = self.cast_metric_to_best_unit(pixel_size[0])
                 _logger.warning(
-                    f"TapeMeasure is only handling square pixels for now. Will consider the pixel is {value:~}{value:~}"
+                    f"TapeMeasure is only handling square pixels for now. Will consider the pixel is {value:.4f~P}x{value:.4f~P}"
                 )
-            pixel_size_m = pixel_size_m[0]
-        self._pixel_size_m = pixel_size_m
+            pixel_size = pixel_size[0]
+        self._pixel_size = pixel_size
 
     @staticmethod
     def cast_metric_to_best_unit(value: pint.Quantity) -> pint.Quantity:
