@@ -4,7 +4,7 @@ import functools
 from typing import Iterable
 
 from silx.gui import qt
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 from tomwer.gui import icons
 from tomwer.utils import docstring
@@ -178,7 +178,7 @@ class FlowCanvas(qt.QWidget):
         self, parent, direction: str | FlowDirection, show_lock_state=True
     ) -> None:
         qt.QWidget.__init__(self, parent=parent)
-        self._direction = FlowDirection.from_value(direction)
+        self._direction = FlowDirection(direction)
         if self._direction is FlowDirection.HORIZONTAL:
             layout = qt.QHBoxLayout()
         elif self._direction is FlowDirection.VERTICAL:
