@@ -4,8 +4,9 @@ import logging
 import os
 
 import numpy
-from nxtomomill.io.config import TomoEDFConfig as EDFConfig
-from nxtomomill.io.config import TomoHDF5Config as HDF5Config
+from nxtomomill.models.h52nx import H52nxModel
+from nxtomomill.models.edf2nx import EDF2nxModel
+
 from silx.gui import qt
 
 from tomoscan.identifier import BaseIdentifier
@@ -54,10 +55,10 @@ class SelectionLineEdit(qt.QWidget):
             fpm = "\\-?\\d*\\.?\\d+"  # float or int matching
         else:
             fpm = "\\d*\\.?\\d+"  # float or int matching
-        qRegExp = qt.QRegExp(
+        qRegExp = qt.QRegularExpression(
             "(" + fpm + "[;]?[,]?[ ]?){1,}" + "|" + ":".join((fpm, fpm, fpm))
         )
-        self._qLineEdit.setValidator(qt.QRegExpValidator(qRegExp))
+        self._qLineEdit.setValidator(qt.QRegularExpressionValidator(qRegExp))
         self.layout().addWidget(self._qLineEdit)
         self._button = SelectionModeButton(parent=self)
         self.layout().addWidget(self._button)
@@ -105,7 +106,7 @@ class SelectionLineEdit(qt.QWidget):
                 else:
                     return tuple(res)
         else:
-            _logger.warning("Wrong input, unvalid selection")
+            _logger.warning("Wrong input, invalid selection")
             return None
 
     def _checkIfModeChanged(self, _str):
@@ -171,7 +172,7 @@ class SelectionModeButton(qt.QToolButton):
         elif mode == SelectionLineEdit.RANGE_MODE:
             return "Define a range of value for this parameter (from:to:step)"
         else:
-            raise ValueError("unknow mode")
+            raise ValueError("unknown mode")
 
     def _modeChanged(self, mode):
         self.mode = mode
@@ -298,7 +299,7 @@ class NXTomomillOutputDirSelector(qt.QWidget):
         dialog = qt.QFileDialog(self, directory=defaultDirectory)
         dialog.setFileMode(qt.QFileDialog.DirectoryOnly)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
@@ -370,7 +371,7 @@ class _ConfigFileSelector(qt.QWidget):
         dialog = qt.QFileDialog(self)
         dialog.setFileMode(qt.QFileDialog.ExistingFile)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
         if len(dialog.selectedFiles()) > 0:
@@ -407,12 +408,12 @@ class _ConfigFileSelector(qt.QWidget):
 
 class HDF5ConfigFileSelector(_ConfigFileSelector):
     def _load_config_file(self, cfg_file: str):
-        HDF5Config.from_cfg_file(cfg_file)
+        H52nxModel.from_cfg_file(cfg_file)
 
 
 class EDFConfigFileSelector(_ConfigFileSelector):
     def _load_config_file(self, cfg_file: str):
-        EDFConfig.from_cfg_file(cfg_file)
+        EDF2nxModel.from_cfg_file(cfg_file)
 
 
 class OutputVolumeDefinition(qt.QWidget):
@@ -488,6 +489,8 @@ class OutputVolumeDefinition(qt.QWidget):
     def selectOutputFile(self, extensions) -> str | None:
         dialog = qt.QFileDialog(self)
         dialog.setNameFilters(extensions)
+        dialog.setAcceptMode(qt.QFileDialog.AcceptSave)
+
         if os.environ.get("TOMWER_DEFAULT_INPUT_DIR", None) and os.path.exists(
             os.environ["TOMWER_DEFAULT_INPUT_DIR"]
         ):
@@ -500,7 +503,7 @@ class OutputVolumeDefinition(qt.QWidget):
         elif os.path.isdir("/data"):
             dialog.setDirectory("/data")
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return None
         else:
@@ -521,7 +524,7 @@ class OutputVolumeDefinition(qt.QWidget):
         elif os.path.isdir("/data"):
             dialog.setDirectory("/data")
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
