@@ -73,7 +73,7 @@ class QSliceSelectorDialog(qt.QDialog):
             qt.QMessageBox.warning(self, "Selection tool not available", mess)
             self.reject()
         else:
-            return qt.QDialog.exec_(self)
+            return qt.QDialog.exec(self)
 
     def nRequiredSlice(self) -> int | None:
         return self.mainWidget.nRequiredSlice()
