@@ -16,7 +16,7 @@ class QComboBoxIgnoreWheel(qt.QComboBox, _IgnoreWheelBase):
     pass
 
 
-class QDoubleSpinBoxIgnoreWheel(qt.QDoubleSpinBox):
+class QDoubleSpinBoxIgnoreWheel(qt.QDoubleSpinBox, _IgnoreWheelBase):
     pass
 
 
