@@ -110,7 +110,7 @@ class MetricEntry(qt.QWidget):
 
         self._qcbUnit = qt.QComboBox(parent=self)
         for unit in self._ExposedUnits:
-            self._qcbUnit.addItem(f"{unit:~}")
+            self._qcbUnit.addItem(f"{unit:.4f~P}")
 
         self.layout().addWidget(self._qcbUnit)
         self._resetBaseUnit()
@@ -163,7 +163,7 @@ class MetricEntry(qt.QWidget):
                 f"'displayed_unit' should be a {pint.Unit}. Got {type(displayed_unit)}"
             )
         displayed_unit = displayed_unit or self._base_unit
-        index = self._qcbUnit.findText(f"{displayed_unit:~}")
+        index = self._qcbUnit.findText(f"{displayed_unit:.4f~P}")
         if index < 0:
             raise ValueError("unrecognized base unit")
         else:
@@ -186,7 +186,7 @@ class MetricEntry(qt.QWidget):
         assert isinstance(
             unit, pint.Unit
         ), f"unit is expected to be a pint.Unit. Got {type(unit)}"
-        unit = f"{unit:~}"
+        unit = f"{unit:.4f~P}"
         idx = self._qcbUnit.findText(unit)
         if idx >= 0:
             self._qcbUnit.setCurrentIndex(idx)
