@@ -21,25 +21,44 @@ __image_j_from = None
 _IMAGE_J_BIN_PATH = "/sware/pub/ImageJ/ImageJ"
 
 
-def has_imagej():
+def has_imagej() -> bool:
     """Return if imagej command is accessible from the computer"""
     global __has_image_j
-    global __image_j_from
-    if __has_image_j is None:
+
+    def has_bin() -> bool:
+        global __image_j_from
         if platform.machine() in ("x86_64", "AMD64") and os.path.exists(
             _IMAGE_J_BIN_PATH
         ):
             __image_j_from = "binary"
-            __has_image_j = True
+            return True
+        return False
+
+    def has_CLI() -> bool:
+        global __image_j_from
+        try:
+            # use help because there is no information regarding version
+            subprocess.call(
+                ["imagej", "-h"], stdout=subprocess.PIPE
+            )  # nosec B603, B607
+        except Exception:
+            return False
         else:
-            try:
-                # use help because there is no information regarding version
-                subprocess.call(["imagej", "-h"], stdout=subprocess.PIPE)
-            except Exception:
-                __has_image_j = False
-            else:
-                __image_j_from = "command"
-                __has_image_j = True
+            __image_j_from = "command"
+            return True
+
+    def has_module() -> bool:
+        """Check if the module exists. At the moment this is the simplest way to access as utils like is-loaded seems to fail."""
+        global __image_j_from
+        if os.path.exists("/cvmfs/hpc.esrf.fr/software/packages/linux/x86_64/imagej"):
+            __image_j_from = "command"
+            return True
+        else:
+            return False
+
+    if __has_image_j is None:
+        __has_image_j = has_bin() or has_CLI() or has_module()
+
     return __has_image_j
 
 
