@@ -298,7 +298,7 @@ class _FramesSelector(qt.QWidget):
 
         dialog = QDataDialog(self, multiSelection=True)
 
-        if not dialog.exec_():
+        if not dialog.exec():
             dialog.close()
             return
 
