@@ -5,11 +5,11 @@ contains gui for diffviewer shift
 """
 from __future__ import annotations
 
+from enum import Enum
 
 import sys
 
 from silx.gui import qt
-from silx.utils.enum import Enum as _Enum
 
 from tomwer.utils import docstring
 
@@ -54,7 +54,7 @@ class TwoFramesShiftTab(qt.QTabWidget, _FrameShiftsBase):
      lrflip is a boolean notifying if we should flip image or not before applying the shift
     """
 
-    class ShiftMode(_Enum):
+    class ShiftMode(Enum):
         RELATIVE = "relative shift"
         ABSOLUTE = "absolute shift"
 
@@ -206,7 +206,7 @@ class Relative2FramesShift(qt.QWidget, _FrameShiftsBase):
         self._controlWidget.setFocus(qt.Qt.OtherFocusReason)
 
     def move(self, direction: str):
-        direction = _ControlArrowWidget.Direction.from_value(direction)
+        direction = _ControlArrowWidget.Direction(direction)
         shift = self._shiftStepSize.value()
         if direction is _ControlArrowWidget.Direction.RIGHT:
             self._xShiftQLE.setValue(self._xShiftQLE.value() + shift)
@@ -290,14 +290,12 @@ class _ControlArrowWidget(qt.QWidget):
     sigMoved = qt.Signal(str)
     """signal emit when one direction is activated. Will contain the direction in which we want to move"""
 
-    class Direction(_Enum):
+    class Direction(Enum):
         LEFT = "left"
         RIGHT = "right"
         UP = "up"
         DOWN = "down"
 
-    VALID_DIRECTIONS = Direction.members()
-
     ARROW_BUTTON_SIZE = 30
 
     QKEY_TO_DIR = {
