@@ -3,7 +3,7 @@ from __future__ import annotations
 import numpy
 import logging
 from silx.gui import qt
-from tomwer.core.utils.char import BETA_CHAR, DELTA_CHAR
+from tomwer.core.utils.char import BETA_CHAR, DELTA_CHAR, MU_CHAR
 
 _logger = logging.getLogger(__name__)
 
@@ -18,7 +18,7 @@ class ReconstructionParameters(qt.QWidget):
         self.setLayout(qt.QFormLayout())
         # method
         self._methodQLE = qt.QLineEdit("", self)
-        self.layout().addRow("method", self._methodQLE)
+        self.layout().addRow("Method", self._methodQLE)
         self._methodQLE.setReadOnly(True)
         # paganin
         self._paganinQLE = qt.QLineEdit("", self)
@@ -30,47 +30,49 @@ class ReconstructionParameters(qt.QWidget):
         self._deltaBetaQLE.setReadOnly(True)
         self.layout().addRow(self._deltaBetaLabel, self._deltaBetaQLE)
         # sample_detector distance
-        self._sampleDetectorDistanceQLE = qt.QLineEdit("", self)
-        self._sampleDetectorDistanceQLE.setReadOnly(True)
+        self._sampleDetectorDistanceInMeterQLE = qt.QLineEdit("", self)
+        self._sampleDetectorDistanceInMeterQLE.setReadOnly(True)
         self.layout().addRow(
-            "sample-detector distance (cm)", self._sampleDetectorDistanceQLE
+            "Sample-detector distance (m)", self._sampleDetectorDistanceInMeterQLE
         )
         # pixel size
-        self._voxelSizeQLE = qt.QLineEdit("", self)
-        self._voxelSizeQLE.setReadOnly(True)
-        self.layout().addRow("voxel size (cm)", self._voxelSizeQLE)
+        self._voxelSizeInMicronQLE = qt.QLineEdit("", self)
+        self._voxelSizeInMicronQLE.setReadOnly(True)
+        self.layout().addRow(f"Voxel size ({MU_CHAR}m)", self._voxelSizeInMicronQLE)
         # cor
         self._corQLE = qt.QLineEdit("", self)
         self._corQLE.setReadOnly(True)
-        self.layout().addRow("cor (absolute)", self._corQLE)
+        self.layout().addRow("CoR (absolute)", self._corQLE)
         # padding type
         self._paddingTypeQLE = qt.QLineEdit("", self)
         self._paddingTypeQLE.setReadOnly(True)
-        self.layout().addRow("padding type", self._paddingTypeQLE)
+        self.layout().addRow("Padding type", self._paddingTypeQLE)
         # half tomo
         self._halfTomoCB = qt.QCheckBox("", self)
         self._halfTomoCB.setEnabled(False)
-        self.layout().addRow("half tomo", self._halfTomoCB)
+        self.layout().addRow("Half tomo", self._halfTomoCB)
         # fbp filter type
         self._fbpFilterQLE = qt.QLineEdit("", self)
         self._fbpFilterQLE.setReadOnly(True)
-        self.layout().addRow("fbp filter", self._fbpFilterQLE)
+        self.layout().addRow("FBP filter", self._fbpFilterQLE)
         # log min clip
         self._minLogClipQLE = qt.QLineEdit("", self)
         self._minLogClipQLE.setReadOnly(True)
-        self.layout().addRow("log min clip", self._minLogClipQLE)
+        self.layout().addRow("Log min clip", self._minLogClipQLE)
         # log max clip
         self._maxLogClipQLE = qt.QLineEdit("", self)
         self._maxLogClipQLE.setReadOnly(True)
-        self.layout().addRow("log max clip", self._maxLogClipQLE)
+        self.layout().addRow("Log max clip", self._maxLogClipQLE)
         # sino normalization & normalization file
         self._sinonormalizationQLE = qt.QLabel("", self)
-        self.layout().addRow("sino normalization", self._sinonormalizationQLE)
+        self.layout().addRow("Sinogram normalization", self._sinonormalizationQLE)
         self._sinonormalizationFileQLE = qt.QLabel("", self)
-        self.layout().addRow("sino normalization file", self._sinonormalizationFileQLE)
+        self.layout().addRow(
+            "Sinogram normalization file", self._sinonormalizationFileQLE
+        )
         # software version
         self._softwareVersionQLE = qt.QLabel("", self)
-        self.layout().addRow("software version", self._softwareVersionQLE)
+        self.layout().addRow("Software version", self._softwareVersionQLE)
 
         # Connect signal for paganinQLE
         self._paganinQLE.textChanged.connect(self._updateDeltaBetaVisibility)
@@ -135,11 +137,11 @@ class ReconstructionParameters(qt.QWidget):
             "sample_detector_dist", None
         )
         if distance_cm not in (None, "", "None"):
-            distance_cm = float(distance_cm)
-            distance_cm = f"{distance_cm:.2}"
+            distance_m = float(distance_cm) / 100.0
+            distance_m = f"{distance_m:.5}"
         else:
-            distance_cm = ""
-        self._sampleDetectorDistanceQLE.setText(distance_cm)
+            distance_m = ""
+        self._sampleDetectorDistanceInMeterQLE.setText(distance_m)
 
     def _setVoxelSize(self, metadata: dict):
         # voxel size can be stored as pixel size (old version) or voxel size (new version)
@@ -166,11 +168,12 @@ class ReconstructionParameters(qt.QWidget):
 
         voxel_size_cm = filter(None, voxel_size_cm)
 
-        def cast_voxel_value(value: float | None):
-            return f"{float(value):.8}"
+        def cast_voxel_value(value_cm: float):
+            value_micron = value_cm * 10_000.0
+            return f"{float(value_micron):.2}"
 
-        voxel_size_cm = [cast_voxel_value(value) for value in voxel_size_cm]
-        self._voxelSizeQLE.setText("x".join(voxel_size_cm))
+        voxel_size_micron = [cast_voxel_value(value) for value in voxel_size_cm]
+        self._voxelSizeInMicronQLE.setText("x".join(voxel_size_micron))
 
     def _setCor(self, metadata: dict):
         cor = (
@@ -239,8 +242,11 @@ class ReconstructionParameters(qt.QWidget):
         self._sinonormalizationQLE.setText(norm_method)
         self._sinonormalizationFileQLE.setText(sino_normalization_file)
         self._sinonormalizationFileQLE.setToolTip(sino_normalization_file)
+        self._sinonormalizationQLE.setVisible(norm_method is not None)
+        self._sinonormalizationFileQLE.setVisible(sino_normalization_file is not None)
 
     def _setSoftwareVersion(self, metadata: dict):
+        # for HDF5 the version is part of the metadata[version] section. For other this is part of metadata[process_info]
         software_version = metadata.get("version", None) or metadata.get(
             "process_info", {}
         ).get("nabu_version", None)
