@@ -23,11 +23,12 @@ def test_nx_editor(
     nx_tomo.instrument.detector.y_pixel_size = 2.5e-6 * _ureg.meter
     nx_tomo.instrument.detector.field_of_view = "Half"
     nx_tomo.instrument.detector.distance = 59.0 * _ureg.meter
-    nx_tomo.instrument.detector.x_flipped = True
-    nx_tomo.instrument.detector.y_flipped = False
+    nx_tomo.instrument.detector.set_transformation_from_x_flipped(True)
+    nx_tomo.instrument.detector.set_transformation_from_y_flipped(False)
     nx_tomo.energy = 12.8 * _ureg.keV
-    nx_tomo.sample.x_translation = numpy.arange(12) * _ureg.meter
-    nx_tomo.sample.z_translation = numpy.arange(2, 14) * _ureg.meter
+    # warning: NXtomo uses McStas coordinate system
+    nx_tomo.sample.z_translation = numpy.arange(12) * _ureg.meter
+    nx_tomo.sample.y_translation = numpy.arange(2, 14) * _ureg.meter
     nx_tomo.instrument.detector.image_key_control = [ImageKey.PROJECTION.value] * 12
     nx_tomo.instrument.detector.data = numpy.empty(shape=(12, 10, 10))
     nx_tomo.sample.rotation_angle = numpy.linspace(0, 180, num=12) * _ureg.degree
@@ -70,8 +71,8 @@ def test_nx_editor(
     assert widget._sampleDetectorDistanceMetricEntry._qcbUnit.currentText() == "m"
 
     assert "Half" == widget._fieldOfViewCB.currentText()
-    assert widget._xFlippedCB.isChecked()
-    assert not widget._yFlippedCB.isChecked()
+    assert widget._lrFlippedCB.isChecked()
+    assert not widget._udFlippedCB.isChecked()
 
     assert "12.8" == widget._energyEntry.text()
 
