@@ -46,8 +46,8 @@ def test_ReconstructionParameters(qtapp, phase_method):  # noqa F401
     assert window._methodQLE.text() == "FBP"
     assert window._paganinQLE.text() == phase_method
     assert window._deltaBetaQLE.text() == "110.0"
-    assert window._sampleDetectorDistanceQLE.text() == "0.4"
-    assert window._voxelSizeQLE.text() == "0.2x0.2x0.2"
+    assert window._sampleDetectorDistanceInMeterQLE.text() == "0.004"
+    assert window._voxelSizeInMicronQLE.text() == "2e+03x2e+03x2e+03"
     assert window._corQLE.text() == "104.00"
     assert window._halfTomoCB.isChecked()
     assert window._fbpFilterQLE.text() == "Hilbert"
