@@ -10,7 +10,7 @@ from glob import glob
 
 import pytest
 from nxtomomill.converter import from_h5_to_nx
-from nxtomomill.io.config.hdf5config import TomoHDF5Config
+from nxtomomill.models.h52nx import H52nxModel
 from silx.gui.utils.testutils import TestCaseQt
 
 from tomwer.core.scan.nxtomoscan import NXtomoScan
@@ -230,7 +230,7 @@ class TestHDFDataTransfert(TestCaseQt):
             self.input_dir, "sample", "sample_29042021", "nx_file.nx"
         )
         # convert it to nx
-        configuration = TomoHDF5Config()
+        configuration = H52nxModel()
         configuration.input_file = self._sample_file
         configuration.output_file = output_file_path
         files_entries = (self._sample_file_entry,)
