@@ -8,13 +8,13 @@ from nxtomomill.nexus.nxtomo import NXtomo
 from orangecanvas.scheme.readwrite import literal_dumps
 from silx.gui.utils.testutils import SignalListener
 from nxtomo.nxobject.nxdetector import ImageKey
-
 from orangecontrib.tomwer.widgets.edit.NXtomoEditorOW import NXtomoEditorOW
 from tomwer.core.process.edit.nxtomoeditor import NXtomoEditorKeys
 from tomwer.core.scan.nxtomoscan import NXtomoScan
 from tomwer.tests.utils import skip_gui_test
 from tomwer.gui.utils.qt_utils import QSignalSpy
 from tomwer.tests.conftest import qtapp  # noqa F401
+from tomwer.tests.test_utils import is_lr_flip, is_ud_flip
 
 _ureg = pint.get_application_registry()
 
@@ -31,8 +31,8 @@ def getDefaultConfig() -> dict:
         NXtomoEditorKeys.DETECTOR_Y_PIXEL_SIZE: (0.025, True),
         NXtomoEditorKeys.SAMPLE_X_PIXEL_SIZE: (0.24, True),
         NXtomoEditorKeys.SAMPLE_Y_PIXEL_SIZE: (0.26, True),
-        NXtomoEditorKeys.X_FLIPPED: (True, True),
-        NXtomoEditorKeys.Y_FLIPPED: (False, False),
+        NXtomoEditorKeys.LR_FLIPPED: (True, True),
+        NXtomoEditorKeys.UD_FLIPPED: (False, False),
         NXtomoEditorKeys.X_TRANSLATION: (0.0,),
         NXtomoEditorKeys.Z_TRANSLATION: (0.0,),
     }
@@ -83,10 +83,10 @@ def test_NXtomoEditorOW(
     nx_tomo.instrument.detector.distance = (
         2.4 * _ureg.meter  # should be overwrite by the configuration / lock buttons
     )
-    nx_tomo.instrument.detector.x_flipped = (
+    nx_tomo.instrument.detector.set_transformation_from_x_flipped(
         False  # should be overwrite by the configuration / lock buttons
     )
-    nx_tomo.instrument.detector.y_flipped = True
+    nx_tomo.instrument.detector.set_transformation_from_y_flipped(True)
     nx_tomo.energy = 5.9 * _ureg.keV
     nx_tomo.instrument.detector.image_key_control = [ImageKey.PROJECTION.value] * 12
     nx_tomo.instrument.detector.data = numpy.empty(shape=(12, 10, 10))
@@ -131,15 +131,20 @@ def test_NXtomoEditorOW(
         overwrite_nx_tomo.instrument.detector.distance.to_base_units().magnitude,
         (6.0e-4 * _ureg.meter).to_base_units().magnitude,
     )
-    assert (
-        overwrite_nx_tomo.instrument.detector.x_flipped
-        == True  # is lock to True so should load the value and overwrite it
-    )
 
     assert (
-        overwrite_nx_tomo.instrument.detector.y_flipped
-        == True  # is not locked and is initially set to False (should load it and ignore overwriting)
+        is_lr_flip(
+            overwrite_nx_tomo.instrument.detector.transformations.transformations
+        )
+        is True
     )
+    assert (
+        is_ud_flip(
+            overwrite_nx_tomo.instrument.detector.transformations.transformations
+        )
+        is True
+    )
+
     numpy.testing.assert_almost_equal(
         overwrite_nx_tomo.energy.to_base_units().magnitude,
         (88.058 * _ureg.keV).to_base_units().magnitude,
