@@ -23,7 +23,7 @@ class TestVolumeViewerOW(TestCaseQt):
     def tearDown(self):
         self._window.setAttribute(qt.Qt.WA_DeleteOnClose)
         self._window.close()
-        del self._window.viewer
+        del self._window._window
         self._window = None
         gc.collect()
 
